@@ -1,4 +1,4 @@
-const baseConfig = require('cdk-build-tools/config/jest.config');
+const baseConfig = require('@aws-cdk/cdk-build-tools/config/jest.config');
 module.exports = {
   ...baseConfig,
   coverageThreshold: {
@@ -7,4 +7,4 @@ module.exports = {
           branches: 70,
       },
   },
-};
\ No newline at end of file
+};
