@@ -13,6 +13,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from .._jsii import *
 
 from .. import (
@@ -63,7 +65,12 @@ class CopyOptions:
                 ignore_mode=monocdk.IgnoreMode.GLOB
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {}
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__3529d837f8a64ef049b1239e4109fa8822d8e4b9887fa501050829ac910e4894)
+            check_type(argname="argument exclude", value=exclude, expected_type=type_hints["exclude"])
+            check_type(argname="argument follow", value=follow, expected_type=type_hints["follow"])
+            check_type(argname="argument ignore_mode", value=ignore_mode, expected_type=type_hints["ignore_mode"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if exclude is not None:
             self._values["exclude"] = exclude
         if follow is not None:
@@ -167,7 +174,13 @@ class FingerprintOptions(CopyOptions):
                 ignore_mode=monocdk.IgnoreMode.GLOB
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {}
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__690abddf789a94bb95c433cec39e9d75e2d7b8a2007f211d5021b6146424bbfa)
+            check_type(argname="argument exclude", value=exclude, expected_type=type_hints["exclude"])
+            check_type(argname="argument follow", value=follow, expected_type=type_hints["follow"])
+            check_type(argname="argument ignore_mode", value=ignore_mode, expected_type=type_hints["ignore_mode"])
+            check_type(argname="argument extra_hash", value=extra_hash, expected_type=type_hints["extra_hash"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if exclude is not None:
             self._values["exclude"] = exclude
         if follow is not None:
@@ -285,7 +298,7 @@ class IAsset(typing_extensions.Protocol):
     :stability: deprecated
     '''
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="sourceHash")
     def source_hash(self) -> builtins.str:
         '''(deprecated) A hash of the source of this asset, which is available at construction time.
@@ -309,7 +322,7 @@ class _IAssetProxy:
 
     __jsii_type__: typing.ClassVar[str] = "monocdk.assets.IAsset"
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="sourceHash")
     def source_hash(self) -> builtins.str:
         '''(deprecated) A hash of the source of this asset, which is available at construction time.
@@ -378,6 +391,10 @@ class Staging(
 
         :stability: deprecated
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__a98f8a7fb2149d85636720c759c3a4da03fafb74fab4332b34cf324a21b77d62)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = StagingProps(
             source_path=source_path,
             extra_hash=extra_hash,
@@ -440,7 +457,14 @@ class StagingProps(FingerprintOptions):
                 ignore_mode=monocdk.IgnoreMode.GLOB
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__ba0262a0f41d81c1dafda4e5045dd1deede21726a75dd38bee5d5a9f7d16693e)
+            check_type(argname="argument exclude", value=exclude, expected_type=type_hints["exclude"])
+            check_type(argname="argument follow", value=follow, expected_type=type_hints["follow"])
+            check_type(argname="argument ignore_mode", value=ignore_mode, expected_type=type_hints["ignore_mode"])
+            check_type(argname="argument extra_hash", value=extra_hash, expected_type=type_hints["extra_hash"])
+            check_type(argname="argument source_path", value=source_path, expected_type=type_hints["source_path"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "source_path": source_path,
         }
         if exclude is not None:
@@ -534,3 +558,46 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__3529d837f8a64ef049b1239e4109fa8822d8e4b9887fa501050829ac910e4894(
+    *,
+    exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+    follow: typing.Optional[FollowMode] = None,
+    ignore_mode: typing.Optional[_IgnoreMode_31d8bf46] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__690abddf789a94bb95c433cec39e9d75e2d7b8a2007f211d5021b6146424bbfa(
+    *,
+    exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+    follow: typing.Optional[FollowMode] = None,
+    ignore_mode: typing.Optional[_IgnoreMode_31d8bf46] = None,
+    extra_hash: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a98f8a7fb2149d85636720c759c3a4da03fafb74fab4332b34cf324a21b77d62(
+    scope: _Construct_e78e779f,
+    id: builtins.str,
+    *,
+    source_path: builtins.str,
+    extra_hash: typing.Optional[builtins.str] = None,
+    exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+    follow: typing.Optional[FollowMode] = None,
+    ignore_mode: typing.Optional[_IgnoreMode_31d8bf46] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ba0262a0f41d81c1dafda4e5045dd1deede21726a75dd38bee5d5a9f7d16693e(
+    *,
+    exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+    follow: typing.Optional[FollowMode] = None,
+    ignore_mode: typing.Optional[_IgnoreMode_31d8bf46] = None,
+    extra_hash: typing.Optional[builtins.str] = None,
+    source_path: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
