@@ -46,9 +46,11 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from .._jsii import *
 
-import constructs
+import constructs as _constructs_77d1e7e8
 from .. import (
     CfnResource as _CfnResource_e0a482dc,
     CfnTag as _CfnTag_95fbdc29,
@@ -111,9 +113,9 @@ class CfnProfilingGroup(
         *,
         profiling_group_name: builtins.str,
         agent_permissions: typing.Any = None,
-        anomaly_detection_notification_configuration: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union["CfnProfilingGroup.ChannelProperty", _IResolvable_a771d0ef]]]] = None,
+        anomaly_detection_notification_configuration: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnProfilingGroup.ChannelProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
         compute_platform: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.Sequence[_CfnTag_95fbdc29]] = None,
+        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''Create a new ``AWS::CodeGuruProfiler::ProfilingGroup``.
 
@@ -125,6 +127,10 @@ class CfnProfilingGroup(
         :param compute_platform: The compute platform of the profiling group. Use ``AWSLambda`` if your application runs on AWS Lambda. Use ``Default`` if your application runs on a compute platform that is not AWS Lambda , such an Amazon EC2 instance, an on-premises server, or a different platform. If not specified, ``Default`` is used. This property is immutable.
         :param tags: A list of tags to add to the created profiling group.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__c147f15afcfd40ccf0c7aa3e75ac50f1434ee102c4251cd3029eef4e0a836265)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnProfilingGroupProps(
             profiling_group_name=profiling_group_name,
             agent_permissions=agent_permissions,
@@ -141,6 +147,9 @@ class CfnProfilingGroup(
 
         :param inspector: - tree inspector to collect and process attributes.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__61a87438de57d97cfd0de7c94f26acdfbf5c06b515b599c4550c3a08e5685547)
+            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
     @jsii.member(jsii_name="renderProperties")
@@ -151,15 +160,18 @@ class CfnProfilingGroup(
         '''
         :param props: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__b730c469c26ceb8ebce53409aba10d990ef7045bf7dff2c3e29d320460dc4876)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
     def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         '''The CloudFormation resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         '''The full Amazon Resource Name (ARN) for that profiling group.
@@ -168,12 +180,12 @@ class CfnProfilingGroup(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_0b7ab120:
         '''A list of tags to add to the created profiling group.
@@ -182,7 +194,7 @@ class CfnProfilingGroup(
         '''
         return typing.cast(_TagManager_0b7ab120, jsii.get(self, "tags"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="agentPermissions")
     def agent_permissions(self) -> typing.Any:
         '''The agent permissions attached to this profiling group.
@@ -199,9 +211,12 @@ class CfnProfilingGroup(
 
     @agent_permissions.setter
     def agent_permissions(self, value: typing.Any) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__84cc55f74d60e23db9bd2320149a9cfb7cf94ee9218da0a4f3f4824ed88e07bc)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "agentPermissions", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="profilingGroupName")
     def profiling_group_name(self) -> builtins.str:
         '''The name of the profiling group.
@@ -212,9 +227,12 @@ class CfnProfilingGroup(
 
     @profiling_group_name.setter
     def profiling_group_name(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__a201710be2f4884bec93ab68a4bc0cca94491d7e54c33e19f37b72b700f03910)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "profilingGroupName", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="anomalyDetectionNotificationConfiguration")
     def anomaly_detection_notification_configuration(
         self,
@@ -230,9 +248,12 @@ class CfnProfilingGroup(
         self,
         value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnProfilingGroup.ChannelProperty", _IResolvable_a771d0ef]]]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__6fe2ee5dad4c228b7578ca5d03f3c76cd906a4bd006eaa3ceb28598988205e83)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "anomalyDetectionNotificationConfiguration", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="computePlatform")
     def compute_platform(self) -> typing.Optional[builtins.str]:
         '''The compute platform of the profiling group.
@@ -245,8 +266,62 @@ class CfnProfilingGroup(
 
     @compute_platform.setter
     def compute_platform(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__8dfa43532e1980fecaeec009d59d2cd3978289134199ed517c2d8239569dd3f7)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "computePlatform", value)
 
+    @jsii.data_type(
+        jsii_type="monocdk.aws_codeguruprofiler.CfnProfilingGroup.AgentPermissionsProperty",
+        jsii_struct_bases=[],
+        name_mapping={"principals": "principals"},
+    )
+    class AgentPermissionsProperty:
+        def __init__(self, *, principals: typing.Sequence[builtins.str]) -> None:
+            '''
+            :param principals: ``CfnProfilingGroup.AgentPermissionsProperty.Principals``.
+
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codeguruprofiler-profilinggroup-agentpermissions.html
+            :exampleMetadata: fixture=_generated
+
+            Example::
+
+                # The code below shows an example of how to instantiate this type.
+                # The values are placeholders you should change.
+                from monocdk import aws_codeguruprofiler as codeguruprofiler
+                
+                agent_permissions_property = codeguruprofiler.CfnProfilingGroup.AgentPermissionsProperty(
+                    principals=["principals"]
+                )
+            '''
+            if __debug__:
+                type_hints = typing.get_type_hints(_typecheckingstub__e054255d739c53c8b081417b87ef9d2ca58659d5a5af88f27a2d383a339bf6fb)
+                check_type(argname="argument principals", value=principals, expected_type=type_hints["principals"])
+            self._values: typing.Dict[builtins.str, typing.Any] = {
+                "principals": principals,
+            }
+
+        @builtins.property
+        def principals(self) -> typing.List[builtins.str]:
+            '''``CfnProfilingGroup.AgentPermissionsProperty.Principals``.
+
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codeguruprofiler-profilinggroup-agentpermissions.html#cfn-codeguruprofiler-profilinggroup-agentpermissions-principals
+            '''
+            result = self._values.get("principals")
+            assert result is not None, "Required property 'principals' is missing"
+            return typing.cast(typing.List[builtins.str], result)
+
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return "AgentPermissionsProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
+
     @jsii.data_type(
         jsii_type="monocdk.aws_codeguruprofiler.CfnProfilingGroup.ChannelProperty",
         jsii_struct_bases=[],
@@ -282,7 +357,11 @@ class CfnProfilingGroup(
                     channel_id="channelId"
                 )
             '''
-            self._values: typing.Dict[str, typing.Any] = {
+            if __debug__:
+                type_hints = typing.get_type_hints(_typecheckingstub__a121df9637198a172138cba1b8ad825df4aeb7df6545d8f12fa2669ccc633f12)
+                check_type(argname="argument channel_uri", value=channel_uri, expected_type=type_hints["channel_uri"])
+                check_type(argname="argument channel_id", value=channel_id, expected_type=type_hints["channel_id"])
+            self._values: typing.Dict[builtins.str, typing.Any] = {
                 "channel_uri": channel_uri,
             }
             if channel_id is not None:
@@ -336,9 +415,9 @@ class CfnProfilingGroupProps:
         *,
         profiling_group_name: builtins.str,
         agent_permissions: typing.Any = None,
-        anomaly_detection_notification_configuration: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[CfnProfilingGroup.ChannelProperty, _IResolvable_a771d0ef]]]] = None,
+        anomaly_detection_notification_configuration: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnProfilingGroup.ChannelProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
         compute_platform: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.Sequence[_CfnTag_95fbdc29]] = None,
+        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''Properties for defining a ``CfnProfilingGroup``.
 
@@ -377,7 +456,14 @@ class CfnProfilingGroupProps:
                 )]
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__be81e62e03c44d7f55ee84a526c4d5efc09f0b896792679dfca84de9719fad4a)
+            check_type(argname="argument profiling_group_name", value=profiling_group_name, expected_type=type_hints["profiling_group_name"])
+            check_type(argname="argument agent_permissions", value=agent_permissions, expected_type=type_hints["agent_permissions"])
+            check_type(argname="argument anomaly_detection_notification_configuration", value=anomaly_detection_notification_configuration, expected_type=type_hints["anomaly_detection_notification_configuration"])
+            check_type(argname="argument compute_platform", value=compute_platform, expected_type=type_hints["compute_platform"])
+            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "profiling_group_name": profiling_group_name,
         }
         if agent_permissions is not None:
@@ -490,7 +576,7 @@ class IProfilingGroup(_IResource_8c1dbbbd, typing_extensions.Protocol):
     :stability: experimental
     '''
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="profilingGroupName")
     def profiling_group_name(self) -> builtins.str:
         '''(experimental) A name for the profiling group.
@@ -532,7 +618,7 @@ class IProfilingGroup(_IResource_8c1dbbbd, typing_extensions.Protocol):
 
 
 class _IProfilingGroupProxy(
-    jsii.proxy_for(_IResource_8c1dbbbd) # type: ignore[misc]
+    jsii.proxy_for(_IResource_8c1dbbbd), # type: ignore[misc]
 ):
     '''(experimental) IResource represents a Profiling Group.
 
@@ -541,7 +627,7 @@ class _IProfilingGroupProxy(
 
     __jsii_type__: typing.ClassVar[str] = "monocdk.aws_codeguruprofiler.IProfilingGroup"
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="profilingGroupName")
     def profiling_group_name(self) -> builtins.str:
         '''(experimental) A name for the profiling group.
@@ -564,6 +650,9 @@ class _IProfilingGroupProxy(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__8834739b5ea420371487cf0f03caf56c32948541887a16fde9df3651c3d60c09)
+            check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(_Grant_bcb5eae7, jsii.invoke(self, "grantPublish", [grantee]))
 
     @jsii.member(jsii_name="grantRead")
@@ -579,6 +668,9 @@ class _IProfilingGroupProxy(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__38ca6c84101cd710d909419b5a367c0b8ed7378c52e464444abc61a1e6224105)
+            check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(_Grant_bcb5eae7, jsii.invoke(self, "grantRead", [grantee]))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
@@ -609,7 +701,7 @@ class ProfilingGroup(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         compute_platform: typing.Optional[ComputePlatform] = None,
@@ -623,6 +715,10 @@ class ProfilingGroup(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__c003743a12aa0af5578e84a26b8eda3544e8c51ddb5d15706efb50891883dcf9)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ProfilingGroupProps(
             compute_platform=compute_platform,
             profiling_group_name=profiling_group_name,
@@ -630,11 +726,11 @@ class ProfilingGroup(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromProfilingGroupArn") # type: ignore[misc]
+    @jsii.member(jsii_name="fromProfilingGroupArn")
     @builtins.classmethod
     def from_profiling_group_arn(
         cls,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         profiling_group_arn: builtins.str,
     ) -> IProfilingGroup:
@@ -646,13 +742,18 @@ class ProfilingGroup(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__bf3c6101a8372f3c5c6e4c8ab8ba224e1072d8cfc76421703ce9143f4466e283)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument profiling_group_arn", value=profiling_group_arn, expected_type=type_hints["profiling_group_arn"])
         return typing.cast(IProfilingGroup, jsii.sinvoke(cls, "fromProfilingGroupArn", [scope, id, profiling_group_arn]))
 
-    @jsii.member(jsii_name="fromProfilingGroupName") # type: ignore[misc]
+    @jsii.member(jsii_name="fromProfilingGroupName")
     @builtins.classmethod
     def from_profiling_group_name(
         cls,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         profiling_group_name: builtins.str,
     ) -> IProfilingGroup:
@@ -664,6 +765,11 @@ class ProfilingGroup(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__f906c2116c11d76a8436f713cfd07d160c1f87be1b8fd189a54ba0ae20a0ff9d)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument profiling_group_name", value=profiling_group_name, expected_type=type_hints["profiling_group_name"])
         return typing.cast(IProfilingGroup, jsii.sinvoke(cls, "fromProfilingGroupName", [scope, id, profiling_group_name]))
 
     @jsii.member(jsii_name="grantPublish")
@@ -679,6 +785,9 @@ class ProfilingGroup(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__8820b833f1d3304aced83e7df51f3e5f48ff6ab79fb01e815adfb1511521b15d)
+            check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(_Grant_bcb5eae7, jsii.invoke(self, "grantPublish", [grantee]))
 
     @jsii.member(jsii_name="grantRead")
@@ -694,9 +803,12 @@ class ProfilingGroup(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__f1c2cf85b2b4a3a4ca39fdb466d8be2308d30db79334a91ead763b0023471bf6)
+            check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(_Grant_bcb5eae7, jsii.invoke(self, "grantRead", [grantee]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="profilingGroupArn")
     def profiling_group_arn(self) -> builtins.str:
         '''(experimental) The ARN of the Profiling Group.
@@ -706,7 +818,7 @@ class ProfilingGroup(
         '''
         return typing.cast(builtins.str, jsii.get(self, "profilingGroupArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="profilingGroupName")
     def profiling_group_name(self) -> builtins.str:
         '''(experimental) The name of the Profiling Group.
@@ -746,7 +858,11 @@ class ProfilingGroupProps:
                 compute_platform=codeguruprofiler.ComputePlatform.AWS_LAMBDA
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {}
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__f5af9828488b902ad2f28a9def533650611b0c99188afb653312375e1292deaf)
+            check_type(argname="argument compute_platform", value=compute_platform, expected_type=type_hints["compute_platform"])
+            check_type(argname="argument profiling_group_name", value=profiling_group_name, expected_type=type_hints["profiling_group_name"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if compute_platform is not None:
             self._values["compute_platform"] = compute_platform
         if profiling_group_name is not None:
@@ -796,3 +912,136 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__c147f15afcfd40ccf0c7aa3e75ac50f1434ee102c4251cd3029eef4e0a836265(
+    scope: _Construct_e78e779f,
+    id: builtins.str,
+    *,
+    profiling_group_name: builtins.str,
+    agent_permissions: typing.Any = None,
+    anomaly_detection_notification_configuration: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnProfilingGroup.ChannelProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
+    compute_platform: typing.Optional[builtins.str] = None,
+    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__61a87438de57d97cfd0de7c94f26acdfbf5c06b515b599c4550c3a08e5685547(
+    inspector: _TreeInspector_1cd1894e,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b730c469c26ceb8ebce53409aba10d990ef7045bf7dff2c3e29d320460dc4876(
+    props: typing.Mapping[builtins.str, typing.Any],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__84cc55f74d60e23db9bd2320149a9cfb7cf94ee9218da0a4f3f4824ed88e07bc(
+    value: typing.Any,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a201710be2f4884bec93ab68a4bc0cca94491d7e54c33e19f37b72b700f03910(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6fe2ee5dad4c228b7578ca5d03f3c76cd906a4bd006eaa3ceb28598988205e83(
+    value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnProfilingGroup.ChannelProperty, _IResolvable_a771d0ef]]]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8dfa43532e1980fecaeec009d59d2cd3978289134199ed517c2d8239569dd3f7(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e054255d739c53c8b081417b87ef9d2ca58659d5a5af88f27a2d383a339bf6fb(
+    *,
+    principals: typing.Sequence[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a121df9637198a172138cba1b8ad825df4aeb7df6545d8f12fa2669ccc633f12(
+    *,
+    channel_uri: builtins.str,
+    channel_id: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__be81e62e03c44d7f55ee84a526c4d5efc09f0b896792679dfca84de9719fad4a(
+    *,
+    profiling_group_name: builtins.str,
+    agent_permissions: typing.Any = None,
+    anomaly_detection_notification_configuration: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnProfilingGroup.ChannelProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
+    compute_platform: typing.Optional[builtins.str] = None,
+    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8834739b5ea420371487cf0f03caf56c32948541887a16fde9df3651c3d60c09(
+    grantee: _IGrantable_4c5a91d1,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__38ca6c84101cd710d909419b5a367c0b8ed7378c52e464444abc61a1e6224105(
+    grantee: _IGrantable_4c5a91d1,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c003743a12aa0af5578e84a26b8eda3544e8c51ddb5d15706efb50891883dcf9(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    compute_platform: typing.Optional[ComputePlatform] = None,
+    profiling_group_name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bf3c6101a8372f3c5c6e4c8ab8ba224e1072d8cfc76421703ce9143f4466e283(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    profiling_group_arn: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f906c2116c11d76a8436f713cfd07d160c1f87be1b8fd189a54ba0ae20a0ff9d(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    profiling_group_name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8820b833f1d3304aced83e7df51f3e5f48ff6ab79fb01e815adfb1511521b15d(
+    grantee: _IGrantable_4c5a91d1,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f1c2cf85b2b4a3a4ca39fdb466d8be2308d30db79334a91ead763b0023471bf6(
+    grantee: _IGrantable_4c5a91d1,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f5af9828488b902ad2f28a9def533650611b0c99188afb653312375e1292deaf(
+    *,
+    compute_platform: typing.Optional[ComputePlatform] = None,
+    profiling_group_name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
