@@ -88,6 +88,19 @@ asset = DockerImageAsset(self, "MyBuildImage",
 )
 ```
 
+You can optionally pass an alternate platform to the `docker build` command by specifying
+the `platform` property:
+
+```python
+from monocdk.aws_ecr_assets import DockerImageAsset, Platform
+
+
+asset = DockerImageAsset(self, "MyBuildImage",
+    directory=path.join(__dirname, "my-image"),
+    platform=Platform.LINUX_ARM64
+)
+```
+
 ## Images from Tarball
 
 Images are loaded from a local tarball, uploaded to ECR by the CDK toolkit and/or your app's CI-CD pipeline, and can be
@@ -165,9 +178,11 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from .._jsii import *
 
-import constructs
+import constructs as _constructs_77d1e7e8
 from .. import (
     CfnResource as _CfnResource_e0a482dc,
     Construct as _Construct_e78e779f,
@@ -209,14 +224,15 @@ class DockerImageAsset(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         directory: builtins.str,
         build_args: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         file: typing.Optional[builtins.str] = None,
-        invalidation: typing.Optional["DockerImageAssetInvalidationOptions"] = None,
+        invalidation: typing.Optional[typing.Union["DockerImageAssetInvalidationOptions", typing.Dict[builtins.str, typing.Any]]] = None,
         network_mode: typing.Optional["NetworkMode"] = None,
+        platform: typing.Optional["Platform"] = None,
         repository_name: typing.Optional[builtins.str] = None,
         target: typing.Optional[builtins.str] = None,
         extra_hash: typing.Optional[builtins.str] = None,
@@ -233,6 +249,7 @@ class DockerImageAsset(
         :param file: (experimental) Path to the Dockerfile (relative to the directory). Default: 'Dockerfile'
         :param invalidation: (experimental) Options to control which parameters are used to invalidate the asset hash. Default: - hash all parameters
         :param network_mode: (experimental) Networking mode for the RUN commands during build. Support docker API 1.25+. Default: - no networking mode specified (the default networking mode ``NetworkMode.DEFAULT`` will be used)
+        :param platform: (experimental) Platform to build for. *Requires Docker Buildx*. Default: - no platform specified (the current machine architecture will be used)
         :param repository_name: (deprecated) ECR repository name. Specify this property if you need to statically address the image, e.g. from a Kubernetes Pod. Note, this is only the repository name, without the registry and the tag parts. Default: - the default ECR repository for CDK assets
         :param target: (experimental) Docker target to build to. Default: - no target
         :param extra_hash: (deprecated) Extra information to encode into the fingerprint (e.g. build instructions and other inputs). Default: - hash is only based on source content
@@ -243,12 +260,17 @@ class DockerImageAsset(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__8c0727d5a6023eb61017733c6357e2cebc315f36e77bb6ff93d937c5a4b48b9e)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = DockerImageAssetProps(
             directory=directory,
             build_args=build_args,
             file=file,
             invalidation=invalidation,
             network_mode=network_mode,
+            platform=platform,
             repository_name=repository_name,
             target=target,
             extra_hash=extra_hash,
@@ -281,9 +303,13 @@ class DockerImageAsset(
         :see: https://github.com/aws/aws-cdk/issues/1432
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__62e1dd2977e409484ab603dbd564e654d2a0a81bc8b6c7b2498e8ab5fecd31fa)
+            check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
+            check_type(argname="argument resource_property", value=resource_property, expected_type=type_hints["resource_property"])
         return typing.cast(None, jsii.invoke(self, "addResourceMetadata", [resource, resource_property]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="assetHash")
     def asset_hash(self) -> builtins.str:
         '''(experimental) A hash of this asset, which is available at construction time.
@@ -296,7 +322,7 @@ class DockerImageAsset(
         '''
         return typing.cast(builtins.str, jsii.get(self, "assetHash"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="sourceHash")
     def source_hash(self) -> builtins.str:
         '''(deprecated) A hash of the source of this asset, which is available at construction time.
@@ -311,7 +337,7 @@ class DockerImageAsset(
         '''
         return typing.cast(builtins.str, jsii.get(self, "sourceHash"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="imageUri")
     def image_uri(self) -> builtins.str:
         '''(experimental) The full URI of the image (including a tag).
@@ -325,9 +351,12 @@ class DockerImageAsset(
 
     @image_uri.setter
     def image_uri(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__4e1480ee5dfbceb2b0f0ec7a38d32fba58b0f6df921520a04fed2eaf9f73672e)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "imageUri", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="repository")
     def repository(self) -> _IRepository_8b4d2894:
         '''(experimental) Repository where the image is stored.
@@ -338,6 +367,9 @@ class DockerImageAsset(
 
     @repository.setter
     def repository(self, value: _IRepository_8b4d2894) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__709d812c7e1ac950d7908286dabff7d2ec1a589d5571f856a379bdcd157acaf8)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repository", value)
 
 
@@ -349,6 +381,7 @@ class DockerImageAsset(
         "extra_hash": "extraHash",
         "file": "file",
         "network_mode": "networkMode",
+        "platform": "platform",
         "repository_name": "repositoryName",
         "target": "target",
     },
@@ -361,6 +394,7 @@ class DockerImageAssetInvalidationOptions:
         extra_hash: typing.Optional[builtins.bool] = None,
         file: typing.Optional[builtins.bool] = None,
         network_mode: typing.Optional[builtins.bool] = None,
+        platform: typing.Optional[builtins.bool] = None,
         repository_name: typing.Optional[builtins.bool] = None,
         target: typing.Optional[builtins.bool] = None,
     ) -> None:
@@ -370,6 +404,7 @@ class DockerImageAssetInvalidationOptions:
         :param extra_hash: (experimental) Use ``extraHash`` while calculating the asset hash. Default: true
         :param file: (experimental) Use ``file`` while calculating the asset hash. Default: true
         :param network_mode: (experimental) Use ``networkMode`` while calculating the asset hash. Default: true
+        :param platform: (experimental) Use ``platform`` while calculating the asset hash. Default: true
         :param repository_name: (experimental) Use ``repositoryName`` while calculating the asset hash. Default: true
         :param target: (experimental) Use ``target`` while calculating the asset hash. Default: true
 
@@ -391,7 +426,16 @@ class DockerImageAssetInvalidationOptions:
                 )
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {}
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__4bde6559ebc1cfe56a982f2928381db4f280488c19b536d59b453a5a30711104)
+            check_type(argname="argument build_args", value=build_args, expected_type=type_hints["build_args"])
+            check_type(argname="argument extra_hash", value=extra_hash, expected_type=type_hints["extra_hash"])
+            check_type(argname="argument file", value=file, expected_type=type_hints["file"])
+            check_type(argname="argument network_mode", value=network_mode, expected_type=type_hints["network_mode"])
+            check_type(argname="argument platform", value=platform, expected_type=type_hints["platform"])
+            check_type(argname="argument repository_name", value=repository_name, expected_type=type_hints["repository_name"])
+            check_type(argname="argument target", value=target, expected_type=type_hints["target"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if build_args is not None:
             self._values["build_args"] = build_args
         if extra_hash is not None:
@@ -400,6 +444,8 @@ class DockerImageAssetInvalidationOptions:
             self._values["file"] = file
         if network_mode is not None:
             self._values["network_mode"] = network_mode
+        if platform is not None:
+            self._values["platform"] = platform
         if repository_name is not None:
             self._values["repository_name"] = repository_name
         if target is not None:
@@ -449,6 +495,17 @@ class DockerImageAssetInvalidationOptions:
         result = self._values.get("network_mode")
         return typing.cast(typing.Optional[builtins.bool], result)
 
+    @builtins.property
+    def platform(self) -> typing.Optional[builtins.bool]:
+        '''(experimental) Use ``platform`` while calculating the asset hash.
+
+        :default: true
+
+        :stability: experimental
+        '''
+        result = self._values.get("platform")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def repository_name(self) -> typing.Optional[builtins.bool]:
         '''(experimental) Use ``repositoryName`` while calculating the asset hash.
@@ -496,6 +553,7 @@ class DockerImageAssetInvalidationOptions:
         "file": "file",
         "invalidation": "invalidation",
         "network_mode": "networkMode",
+        "platform": "platform",
         "repository_name": "repositoryName",
         "target": "target",
     },
@@ -514,8 +572,9 @@ class DockerImageAssetOptions(
         follow_symlinks: typing.Optional[_SymlinkFollowMode_abf4527a] = None,
         build_args: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         file: typing.Optional[builtins.str] = None,
-        invalidation: typing.Optional[DockerImageAssetInvalidationOptions] = None,
+        invalidation: typing.Optional[typing.Union[DockerImageAssetInvalidationOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         network_mode: typing.Optional["NetworkMode"] = None,
+        platform: typing.Optional["Platform"] = None,
         repository_name: typing.Optional[builtins.str] = None,
         target: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -530,6 +589,7 @@ class DockerImageAssetOptions(
         :param file: (experimental) Path to the Dockerfile (relative to the directory). Default: 'Dockerfile'
         :param invalidation: (experimental) Options to control which parameters are used to invalidate the asset hash. Default: - hash all parameters
         :param network_mode: (experimental) Networking mode for the RUN commands during build. Support docker API 1.25+. Default: - no networking mode specified (the default networking mode ``NetworkMode.DEFAULT`` will be used)
+        :param platform: (experimental) Platform to build for. *Requires Docker Buildx*. Default: - no platform specified (the current machine architecture will be used)
         :param repository_name: (deprecated) ECR repository name. Specify this property if you need to statically address the image, e.g. from a Kubernetes Pod. Note, this is only the repository name, without the registry and the tag parts. Default: - the default ECR repository for CDK assets
         :param target: (experimental) Docker target to build to. Default: - no target
 
@@ -545,6 +605,7 @@ class DockerImageAssetOptions(
             from monocdk import aws_ecr_assets as ecr_assets
             
             # network_mode: ecr_assets.NetworkMode
+            # platform: ecr_assets.Platform
             
             docker_image_asset_options = ecr_assets.DockerImageAssetOptions(
                 build_args={
@@ -561,17 +622,33 @@ class DockerImageAssetOptions(
                     extra_hash=False,
                     file=False,
                     network_mode=False,
+                    platform=False,
                     repository_name=False,
                     target=False
                 ),
                 network_mode=network_mode,
+                platform=platform,
                 repository_name="repositoryName",
                 target="target"
             )
         '''
         if isinstance(invalidation, dict):
             invalidation = DockerImageAssetInvalidationOptions(**invalidation)
-        self._values: typing.Dict[str, typing.Any] = {}
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__bd85fe639e8b90415ad81a921f630204a8c2dea3d01cb26648460596f0fd1508)
+            check_type(argname="argument exclude", value=exclude, expected_type=type_hints["exclude"])
+            check_type(argname="argument follow", value=follow, expected_type=type_hints["follow"])
+            check_type(argname="argument ignore_mode", value=ignore_mode, expected_type=type_hints["ignore_mode"])
+            check_type(argname="argument extra_hash", value=extra_hash, expected_type=type_hints["extra_hash"])
+            check_type(argname="argument follow_symlinks", value=follow_symlinks, expected_type=type_hints["follow_symlinks"])
+            check_type(argname="argument build_args", value=build_args, expected_type=type_hints["build_args"])
+            check_type(argname="argument file", value=file, expected_type=type_hints["file"])
+            check_type(argname="argument invalidation", value=invalidation, expected_type=type_hints["invalidation"])
+            check_type(argname="argument network_mode", value=network_mode, expected_type=type_hints["network_mode"])
+            check_type(argname="argument platform", value=platform, expected_type=type_hints["platform"])
+            check_type(argname="argument repository_name", value=repository_name, expected_type=type_hints["repository_name"])
+            check_type(argname="argument target", value=target, expected_type=type_hints["target"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if exclude is not None:
             self._values["exclude"] = exclude
         if follow is not None:
@@ -590,6 +667,8 @@ class DockerImageAssetOptions(
             self._values["invalidation"] = invalidation
         if network_mode is not None:
             self._values["network_mode"] = network_mode
+        if platform is not None:
+            self._values["platform"] = platform
         if repository_name is not None:
             self._values["repository_name"] = repository_name
         if target is not None:
@@ -702,6 +781,19 @@ class DockerImageAssetOptions(
         result = self._values.get("network_mode")
         return typing.cast(typing.Optional["NetworkMode"], result)
 
+    @builtins.property
+    def platform(self) -> typing.Optional["Platform"]:
+        '''(experimental) Platform to build for.
+
+        *Requires Docker Buildx*.
+
+        :default: - no platform specified (the current machine architecture will be used)
+
+        :stability: experimental
+        '''
+        result = self._values.get("platform")
+        return typing.cast(typing.Optional["Platform"], result)
+
     @builtins.property
     def repository_name(self) -> typing.Optional[builtins.str]:
         '''(deprecated) ECR repository name.
@@ -759,6 +851,7 @@ class DockerImageAssetOptions(
         "file": "file",
         "invalidation": "invalidation",
         "network_mode": "networkMode",
+        "platform": "platform",
         "repository_name": "repositoryName",
         "target": "target",
         "directory": "directory",
@@ -775,8 +868,9 @@ class DockerImageAssetProps(DockerImageAssetOptions):
         follow_symlinks: typing.Optional[_SymlinkFollowMode_abf4527a] = None,
         build_args: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         file: typing.Optional[builtins.str] = None,
-        invalidation: typing.Optional[DockerImageAssetInvalidationOptions] = None,
+        invalidation: typing.Optional[typing.Union[DockerImageAssetInvalidationOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         network_mode: typing.Optional["NetworkMode"] = None,
+        platform: typing.Optional["Platform"] = None,
         repository_name: typing.Optional[builtins.str] = None,
         target: typing.Optional[builtins.str] = None,
         directory: builtins.str,
@@ -792,6 +886,7 @@ class DockerImageAssetProps(DockerImageAssetOptions):
         :param file: (experimental) Path to the Dockerfile (relative to the directory). Default: 'Dockerfile'
         :param invalidation: (experimental) Options to control which parameters are used to invalidate the asset hash. Default: - hash all parameters
         :param network_mode: (experimental) Networking mode for the RUN commands during build. Support docker API 1.25+. Default: - no networking mode specified (the default networking mode ``NetworkMode.DEFAULT`` will be used)
+        :param platform: (experimental) Platform to build for. *Requires Docker Buildx*. Default: - no platform specified (the current machine architecture will be used)
         :param repository_name: (deprecated) ECR repository name. Specify this property if you need to statically address the image, e.g. from a Kubernetes Pod. Note, this is only the repository name, without the registry and the tag parts. Default: - the default ECR repository for CDK assets
         :param target: (experimental) Docker target to build to. Default: - no target
         :param directory: (experimental) The directory where the Dockerfile is stored. Any directory inside with a name that matches the CDK output folder (cdk.out by default) will be excluded from the asset
@@ -816,7 +911,22 @@ class DockerImageAssetProps(DockerImageAssetOptions):
         '''
         if isinstance(invalidation, dict):
             invalidation = DockerImageAssetInvalidationOptions(**invalidation)
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__dded451b85a92144211a75c2e9360ed71dc8ad51d88f4847d9fefef9f9a4bbd7)
+            check_type(argname="argument exclude", value=exclude, expected_type=type_hints["exclude"])
+            check_type(argname="argument follow", value=follow, expected_type=type_hints["follow"])
+            check_type(argname="argument ignore_mode", value=ignore_mode, expected_type=type_hints["ignore_mode"])
+            check_type(argname="argument extra_hash", value=extra_hash, expected_type=type_hints["extra_hash"])
+            check_type(argname="argument follow_symlinks", value=follow_symlinks, expected_type=type_hints["follow_symlinks"])
+            check_type(argname="argument build_args", value=build_args, expected_type=type_hints["build_args"])
+            check_type(argname="argument file", value=file, expected_type=type_hints["file"])
+            check_type(argname="argument invalidation", value=invalidation, expected_type=type_hints["invalidation"])
+            check_type(argname="argument network_mode", value=network_mode, expected_type=type_hints["network_mode"])
+            check_type(argname="argument platform", value=platform, expected_type=type_hints["platform"])
+            check_type(argname="argument repository_name", value=repository_name, expected_type=type_hints["repository_name"])
+            check_type(argname="argument target", value=target, expected_type=type_hints["target"])
+            check_type(argname="argument directory", value=directory, expected_type=type_hints["directory"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "directory": directory,
         }
         if exclude is not None:
@@ -837,6 +947,8 @@ class DockerImageAssetProps(DockerImageAssetOptions):
             self._values["invalidation"] = invalidation
         if network_mode is not None:
             self._values["network_mode"] = network_mode
+        if platform is not None:
+            self._values["platform"] = platform
         if repository_name is not None:
             self._values["repository_name"] = repository_name
         if target is not None:
@@ -949,6 +1061,19 @@ class DockerImageAssetProps(DockerImageAssetOptions):
         result = self._values.get("network_mode")
         return typing.cast(typing.Optional["NetworkMode"], result)
 
+    @builtins.property
+    def platform(self) -> typing.Optional["Platform"]:
+        '''(experimental) Platform to build for.
+
+        *Requires Docker Buildx*.
+
+        :default: - no platform specified (the current machine architecture will be used)
+
+        :stability: experimental
+        '''
+        result = self._values.get("platform")
+        return typing.cast(typing.Optional["Platform"], result)
+
     @builtins.property
     def repository_name(self) -> typing.Optional[builtins.str]:
         '''(deprecated) ECR repository name.
@@ -1025,7 +1150,7 @@ class NetworkMode(
         )
     '''
 
-    @jsii.member(jsii_name="custom") # type: ignore[misc]
+    @jsii.member(jsii_name="custom")
     @builtins.classmethod
     def custom(cls, mode: builtins.str) -> "NetworkMode":
         '''(experimental) Used to specify a custom networking mode Use this if the networking mode name is not yet supported by the CDK.
@@ -1034,9 +1159,12 @@ class NetworkMode(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__57e3c54110ce6e21974e00447a326760a01024ab8dc16d14845c47526b4f55b4)
+            check_type(argname="argument mode", value=mode, expected_type=type_hints["mode"])
         return typing.cast("NetworkMode", jsii.sinvoke(cls, "custom", [mode]))
 
-    @jsii.member(jsii_name="fromContainer") # type: ignore[misc]
+    @jsii.member(jsii_name="fromContainer")
     @builtins.classmethod
     def from_container(cls, container_id: builtins.str) -> "NetworkMode":
         '''(experimental) Reuse another container's network stack.
@@ -1045,9 +1173,12 @@ class NetworkMode(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__f81671deaeca4502b059ceea940d20080048e729e10a8c3394f1753610e5e2f4)
+            check_type(argname="argument container_id", value=container_id, expected_type=type_hints["container_id"])
         return typing.cast("NetworkMode", jsii.sinvoke(cls, "fromContainer", [container_id]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="DEFAULT")
     def DEFAULT(cls) -> "NetworkMode":
         '''(experimental) The default networking mode if omitted, create a network stack on the default Docker bridge.
@@ -1056,7 +1187,7 @@ class NetworkMode(
         '''
         return typing.cast("NetworkMode", jsii.sget(cls, "DEFAULT"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="HOST")
     def HOST(cls) -> "NetworkMode":
         '''(experimental) Use the Docker host network stack.
@@ -1065,7 +1196,7 @@ class NetworkMode(
         '''
         return typing.cast("NetworkMode", jsii.sget(cls, "HOST"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="NONE")
     def NONE(cls) -> "NetworkMode":
         '''(experimental) Disable the network stack, only the loopback device will be created.
@@ -1074,7 +1205,7 @@ class NetworkMode(
         '''
         return typing.cast("NetworkMode", jsii.sget(cls, "NONE"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="mode")
     def mode(self) -> builtins.str:
         '''(experimental) The networking mode to use for docker build.
@@ -1084,6 +1215,65 @@ class NetworkMode(
         return typing.cast(builtins.str, jsii.get(self, "mode"))
 
 
+class Platform(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_ecr_assets.Platform"):
+    '''(experimental) platform supported by docker.
+
+    :stability: experimental
+    :exampleMetadata: infused
+
+    Example::
+
+        from monocdk.aws_ecr_assets import DockerImageAsset, Platform
+        
+        
+        asset = DockerImageAsset(self, "MyBuildImage",
+            directory=path.join(__dirname, "my-image"),
+            platform=Platform.LINUX_ARM64
+        )
+    '''
+
+    @jsii.member(jsii_name="custom")
+    @builtins.classmethod
+    def custom(cls, platform: builtins.str) -> "Platform":
+        '''(experimental) Used to specify a custom platform Use this if the platform name is not yet supported by the CDK.
+
+        :param platform: The platform to use for docker build.
+
+        :stability: experimental
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__b2539695bc8d3e72da12aa88815ecd2544da12c2f08d8866eaa834cdba6ff276)
+            check_type(argname="argument platform", value=platform, expected_type=type_hints["platform"])
+        return typing.cast("Platform", jsii.sinvoke(cls, "custom", [platform]))
+
+    @jsii.python.classproperty
+    @jsii.member(jsii_name="LINUX_AMD64")
+    def LINUX_AMD64(cls) -> "Platform":
+        '''(experimental) Build for linux/amd64.
+
+        :stability: experimental
+        '''
+        return typing.cast("Platform", jsii.sget(cls, "LINUX_AMD64"))
+
+    @jsii.python.classproperty
+    @jsii.member(jsii_name="LINUX_ARM64")
+    def LINUX_ARM64(cls) -> "Platform":
+        '''(experimental) Build for linux/arm64.
+
+        :stability: experimental
+        '''
+        return typing.cast("Platform", jsii.sget(cls, "LINUX_ARM64"))
+
+    @builtins.property
+    @jsii.member(jsii_name="platform")
+    def platform(self) -> builtins.str:
+        '''(experimental) The platform to use for docker build.
+
+        :stability: experimental
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "platform"))
+
+
 @jsii.implements(_IAsset_092a7035)
 class TarballImageAsset(
     _Construct_e78e779f,
@@ -1109,7 +1299,7 @@ class TarballImageAsset(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         tarball_file: builtins.str,
@@ -1121,11 +1311,15 @@ class TarballImageAsset(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__ff0ed9bef8a6bdd4fe1d2fc3d70294320a21d6aea836b6c69345c5dc07d12f16)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = TarballImageAssetProps(tarball_file=tarball_file)
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="assetHash")
     def asset_hash(self) -> builtins.str:
         '''(experimental) A hash of this asset, which is available at construction time.
@@ -1138,7 +1332,7 @@ class TarballImageAsset(
         '''
         return typing.cast(builtins.str, jsii.get(self, "assetHash"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="sourceHash")
     def source_hash(self) -> builtins.str:
         '''(deprecated) A hash of the source of this asset, which is available at construction time.
@@ -1153,7 +1347,7 @@ class TarballImageAsset(
         '''
         return typing.cast(builtins.str, jsii.get(self, "sourceHash"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="imageUri")
     def image_uri(self) -> builtins.str:
         '''(experimental) The full URI of the image (including a tag).
@@ -1167,9 +1361,12 @@ class TarballImageAsset(
 
     @image_uri.setter
     def image_uri(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__6ff2361a3a2ee62fe13f227cb062b02c29585c0db8de4863f90a1bc57c9fb265)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "imageUri", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="repository")
     def repository(self) -> _IRepository_8b4d2894:
         '''(experimental) Repository where the image is stored.
@@ -1180,6 +1377,9 @@ class TarballImageAsset(
 
     @repository.setter
     def repository(self, value: _IRepository_8b4d2894) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__0d7771c1984230f428b30ae2c0a98cd6d8cd53ff2bab6fc0a5df6825475332fb)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repository", value)
 
 
@@ -1206,7 +1406,10 @@ class TarballImageAssetProps:
                 tarball_file="local-image.tar"
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__361e75a0bb42b4963ee48b94a8824c2b78440f701c41506d0caead7e4cb2ada5)
+            check_type(argname="argument tarball_file", value=tarball_file, expected_type=type_hints["tarball_file"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "tarball_file": tarball_file,
         }
 
@@ -1242,8 +1445,145 @@ __all__ = [
     "DockerImageAssetOptions",
     "DockerImageAssetProps",
     "NetworkMode",
+    "Platform",
     "TarballImageAsset",
     "TarballImageAssetProps",
 ]
 
 publication.publish()
+
+def _typecheckingstub__8c0727d5a6023eb61017733c6357e2cebc315f36e77bb6ff93d937c5a4b48b9e(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    directory: builtins.str,
+    build_args: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    file: typing.Optional[builtins.str] = None,
+    invalidation: typing.Optional[typing.Union[DockerImageAssetInvalidationOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+    network_mode: typing.Optional[NetworkMode] = None,
+    platform: typing.Optional[Platform] = None,
+    repository_name: typing.Optional[builtins.str] = None,
+    target: typing.Optional[builtins.str] = None,
+    extra_hash: typing.Optional[builtins.str] = None,
+    exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+    follow: typing.Optional[_FollowMode_98b05cc5] = None,
+    ignore_mode: typing.Optional[_IgnoreMode_31d8bf46] = None,
+    follow_symlinks: typing.Optional[_SymlinkFollowMode_abf4527a] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__62e1dd2977e409484ab603dbd564e654d2a0a81bc8b6c7b2498e8ab5fecd31fa(
+    resource: _CfnResource_e0a482dc,
+    resource_property: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4e1480ee5dfbceb2b0f0ec7a38d32fba58b0f6df921520a04fed2eaf9f73672e(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__709d812c7e1ac950d7908286dabff7d2ec1a589d5571f856a379bdcd157acaf8(
+    value: _IRepository_8b4d2894,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4bde6559ebc1cfe56a982f2928381db4f280488c19b536d59b453a5a30711104(
+    *,
+    build_args: typing.Optional[builtins.bool] = None,
+    extra_hash: typing.Optional[builtins.bool] = None,
+    file: typing.Optional[builtins.bool] = None,
+    network_mode: typing.Optional[builtins.bool] = None,
+    platform: typing.Optional[builtins.bool] = None,
+    repository_name: typing.Optional[builtins.bool] = None,
+    target: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bd85fe639e8b90415ad81a921f630204a8c2dea3d01cb26648460596f0fd1508(
+    *,
+    exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+    follow: typing.Optional[_FollowMode_98b05cc5] = None,
+    ignore_mode: typing.Optional[_IgnoreMode_31d8bf46] = None,
+    extra_hash: typing.Optional[builtins.str] = None,
+    follow_symlinks: typing.Optional[_SymlinkFollowMode_abf4527a] = None,
+    build_args: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    file: typing.Optional[builtins.str] = None,
+    invalidation: typing.Optional[typing.Union[DockerImageAssetInvalidationOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+    network_mode: typing.Optional[NetworkMode] = None,
+    platform: typing.Optional[Platform] = None,
+    repository_name: typing.Optional[builtins.str] = None,
+    target: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__dded451b85a92144211a75c2e9360ed71dc8ad51d88f4847d9fefef9f9a4bbd7(
+    *,
+    exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+    follow: typing.Optional[_FollowMode_98b05cc5] = None,
+    ignore_mode: typing.Optional[_IgnoreMode_31d8bf46] = None,
+    extra_hash: typing.Optional[builtins.str] = None,
+    follow_symlinks: typing.Optional[_SymlinkFollowMode_abf4527a] = None,
+    build_args: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    file: typing.Optional[builtins.str] = None,
+    invalidation: typing.Optional[typing.Union[DockerImageAssetInvalidationOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+    network_mode: typing.Optional[NetworkMode] = None,
+    platform: typing.Optional[Platform] = None,
+    repository_name: typing.Optional[builtins.str] = None,
+    target: typing.Optional[builtins.str] = None,
+    directory: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__57e3c54110ce6e21974e00447a326760a01024ab8dc16d14845c47526b4f55b4(
+    mode: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f81671deaeca4502b059ceea940d20080048e729e10a8c3394f1753610e5e2f4(
+    container_id: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b2539695bc8d3e72da12aa88815ecd2544da12c2f08d8866eaa834cdba6ff276(
+    platform: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ff0ed9bef8a6bdd4fe1d2fc3d70294320a21d6aea836b6c69345c5dc07d12f16(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    tarball_file: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6ff2361a3a2ee62fe13f227cb062b02c29585c0db8de4863f90a1bc57c9fb265(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0d7771c1984230f428b30ae2c0a98cd6d8cd53ff2bab6fc0a5df6825475332fb(
+    value: _IRepository_8b4d2894,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__361e75a0bb42b4963ee48b94a8824c2b78440f701c41506d0caead7e4cb2ada5(
+    *,
+    tarball_file: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
