@@ -21,9 +21,11 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from .._jsii import *
 
-import constructs
+import constructs as _constructs_77d1e7e8
 from .. import Duration as _Duration_070aa057, Size as _Size_7fbd4337
 from ..aws_iam import IRole as _IRole_59af6f50
 from ..aws_kinesisfirehose import (
@@ -149,7 +151,7 @@ class CommonDestinationProps:
         log_group: typing.Optional[_ILogGroup_846e17a0] = None,
         processor: typing.Optional[_IDataProcessor_682cbcf2] = None,
         role: typing.Optional[_IRole_59af6f50] = None,
-        s3_backup: typing.Optional["DestinationS3BackupProps"] = None,
+        s3_backup: typing.Optional[typing.Union["DestinationS3BackupProps", typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''(experimental) Generic properties for defining a delivery stream destination.
 
@@ -204,7 +206,14 @@ class CommonDestinationProps:
         '''
         if isinstance(s3_backup, dict):
             s3_backup = DestinationS3BackupProps(**s3_backup)
-        self._values: typing.Dict[str, typing.Any] = {}
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__bd511ae6ed3054296246be9b4f22db1724e5b257f984289b76ea3dbeb7895c24)
+            check_type(argname="argument logging", value=logging, expected_type=type_hints["logging"])
+            check_type(argname="argument log_group", value=log_group, expected_type=type_hints["log_group"])
+            check_type(argname="argument processor", value=processor, expected_type=type_hints["processor"])
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
+            check_type(argname="argument s3_backup", value=s3_backup, expected_type=type_hints["s3_backup"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if logging is not None:
             self._values["logging"] = logging
         if log_group is not None:
@@ -344,7 +353,15 @@ class CommonDestinationS3Props:
                 error_output_prefix="errorOutputPrefix"
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {}
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__1b561016860cc7ad4535eb67c8a87c2986771bfa20db66cfb07780323fccce65)
+            check_type(argname="argument buffering_interval", value=buffering_interval, expected_type=type_hints["buffering_interval"])
+            check_type(argname="argument buffering_size", value=buffering_size, expected_type=type_hints["buffering_size"])
+            check_type(argname="argument compression", value=compression, expected_type=type_hints["compression"])
+            check_type(argname="argument data_output_prefix", value=data_output_prefix, expected_type=type_hints["data_output_prefix"])
+            check_type(argname="argument encryption_key", value=encryption_key, expected_type=type_hints["encryption_key"])
+            check_type(argname="argument error_output_prefix", value=error_output_prefix, expected_type=type_hints["error_output_prefix"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if buffering_interval is not None:
             self._values["buffering_interval"] = buffering_interval
         if buffering_size is not None:
@@ -535,7 +552,7 @@ class Compression(
         app.synth()
     '''
 
-    @jsii.member(jsii_name="of") # type: ignore[misc]
+    @jsii.member(jsii_name="of")
     @builtins.classmethod
     def of(cls, value: builtins.str) -> "Compression":
         '''(experimental) Creates a new Compression instance with a custom value.
@@ -544,9 +561,12 @@ class Compression(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__ec0614acdfc1b67db37f900a22a765af6efa4f5538cbf88bc8ad0ec4e8924f7d)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         return typing.cast("Compression", jsii.sinvoke(cls, "of", [value]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="GZIP")
     def GZIP(cls) -> "Compression":
         '''(experimental) gzip.
@@ -555,7 +575,7 @@ class Compression(
         '''
         return typing.cast("Compression", jsii.sget(cls, "GZIP"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="HADOOP_SNAPPY")
     def HADOOP_SNAPPY(cls) -> "Compression":
         '''(experimental) Hadoop-compatible Snappy.
@@ -564,7 +584,7 @@ class Compression(
         '''
         return typing.cast("Compression", jsii.sget(cls, "HADOOP_SNAPPY"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="SNAPPY")
     def SNAPPY(cls) -> "Compression":
         '''(experimental) Snappy.
@@ -573,7 +593,7 @@ class Compression(
         '''
         return typing.cast("Compression", jsii.sget(cls, "SNAPPY"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="ZIP")
     def ZIP(cls) -> "Compression":
         '''(experimental) ZIP.
@@ -582,7 +602,7 @@ class Compression(
         '''
         return typing.cast("Compression", jsii.sget(cls, "ZIP"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="value")
     def value(self) -> builtins.str:
         '''(experimental) the string value of the Compression.
@@ -714,7 +734,19 @@ class DestinationS3BackupProps(CommonDestinationS3Props):
             
             app.synth()
         '''
-        self._values: typing.Dict[str, typing.Any] = {}
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__9c28be58770149688b1c550c97a6f5f8b0e585ad9440177bc45ed06cb229093f)
+            check_type(argname="argument buffering_interval", value=buffering_interval, expected_type=type_hints["buffering_interval"])
+            check_type(argname="argument buffering_size", value=buffering_size, expected_type=type_hints["buffering_size"])
+            check_type(argname="argument compression", value=compression, expected_type=type_hints["compression"])
+            check_type(argname="argument data_output_prefix", value=data_output_prefix, expected_type=type_hints["data_output_prefix"])
+            check_type(argname="argument encryption_key", value=encryption_key, expected_type=type_hints["encryption_key"])
+            check_type(argname="argument error_output_prefix", value=error_output_prefix, expected_type=type_hints["error_output_prefix"])
+            check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
+            check_type(argname="argument logging", value=logging, expected_type=type_hints["logging"])
+            check_type(argname="argument log_group", value=log_group, expected_type=type_hints["log_group"])
+            check_type(argname="argument mode", value=mode, expected_type=type_hints["mode"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if buffering_interval is not None:
             self._values["buffering_interval"] = buffering_interval
         if buffering_size is not None:
@@ -897,7 +929,7 @@ class S3Bucket(
         # Provide a Lambda function that will transform records before delivery, with custom
         # buffering and retry configuration
         lambda_function = lambda_.Function(self, "Processor",
-            runtime=lambda_.Runtime.NODEJS_12_X,
+            runtime=lambda_.Runtime.NODEJS_14_X,
             handler="index.handler",
             code=lambda_.Code.from_asset(path.join(__dirname, "process-records"))
         )
@@ -928,7 +960,7 @@ class S3Bucket(
         log_group: typing.Optional[_ILogGroup_846e17a0] = None,
         processor: typing.Optional[_IDataProcessor_682cbcf2] = None,
         role: typing.Optional[_IRole_59af6f50] = None,
-        s3_backup: typing.Optional[DestinationS3BackupProps] = None,
+        s3_backup: typing.Optional[typing.Union[DestinationS3BackupProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param bucket: -
@@ -946,6 +978,9 @@ class S3Bucket(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__0edb78d0af508eb4c1e4d62d539eac5b43009d86df9c681ae7f03915b7d4f439)
+            check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
         props = S3BucketProps(
             buffering_interval=buffering_interval,
             buffering_size=buffering_size,
@@ -963,7 +998,10 @@ class S3Bucket(
         jsii.create(self.__class__, self, [bucket, props])
 
     @jsii.member(jsii_name="bind")
-    def bind(self, scope: constructs.Construct) -> _DestinationConfig_9a0983fa:
+    def bind(
+        self,
+        scope: _constructs_77d1e7e8.Construct,
+    ) -> _DestinationConfig_9a0983fa:
         '''(experimental) Binds this destination to the Kinesis Data Firehose delivery stream.
 
         Implementers should use this method to bind resources to the stack and initialize values using the provided stream.
@@ -972,6 +1010,9 @@ class S3Bucket(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__8ac9b461ea8e1276bf30a0f831affc8f191991843dbd4d749ef73e0cb1f3b898)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
         _options = _DestinationBindOptions_b23afe8e()
 
         return typing.cast(_DestinationConfig_9a0983fa, jsii.invoke(self, "bind", [scope, _options]))
@@ -1008,7 +1049,7 @@ class S3BucketProps(CommonDestinationS3Props, CommonDestinationProps):
         log_group: typing.Optional[_ILogGroup_846e17a0] = None,
         processor: typing.Optional[_IDataProcessor_682cbcf2] = None,
         role: typing.Optional[_IRole_59af6f50] = None,
-        s3_backup: typing.Optional[DestinationS3BackupProps] = None,
+        s3_backup: typing.Optional[typing.Union[DestinationS3BackupProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''(experimental) Props for defining an S3 destination of a Kinesis Data Firehose delivery stream.
 
@@ -1033,7 +1074,7 @@ class S3BucketProps(CommonDestinationS3Props, CommonDestinationProps):
             # Provide a Lambda function that will transform records before delivery, with custom
             # buffering and retry configuration
             lambda_function = lambda_.Function(self, "Processor",
-                runtime=lambda_.Runtime.NODEJS_12_X,
+                runtime=lambda_.Runtime.NODEJS_14_X,
                 handler="index.handler",
                 code=lambda_.Code.from_asset(path.join(__dirname, "process-records"))
             )
@@ -1051,7 +1092,20 @@ class S3BucketProps(CommonDestinationS3Props, CommonDestinationProps):
         '''
         if isinstance(s3_backup, dict):
             s3_backup = DestinationS3BackupProps(**s3_backup)
-        self._values: typing.Dict[str, typing.Any] = {}
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__2056623d400a1e5d9a2ddee016d09ec8fdd804c0598fdecc8719f74c760e4cc5)
+            check_type(argname="argument buffering_interval", value=buffering_interval, expected_type=type_hints["buffering_interval"])
+            check_type(argname="argument buffering_size", value=buffering_size, expected_type=type_hints["buffering_size"])
+            check_type(argname="argument compression", value=compression, expected_type=type_hints["compression"])
+            check_type(argname="argument data_output_prefix", value=data_output_prefix, expected_type=type_hints["data_output_prefix"])
+            check_type(argname="argument encryption_key", value=encryption_key, expected_type=type_hints["encryption_key"])
+            check_type(argname="argument error_output_prefix", value=error_output_prefix, expected_type=type_hints["error_output_prefix"])
+            check_type(argname="argument logging", value=logging, expected_type=type_hints["logging"])
+            check_type(argname="argument log_group", value=log_group, expected_type=type_hints["log_group"])
+            check_type(argname="argument processor", value=processor, expected_type=type_hints["processor"])
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
+            check_type(argname="argument s3_backup", value=s3_backup, expected_type=type_hints["s3_backup"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if buffering_interval is not None:
             self._values["buffering_interval"] = buffering_interval
         if buffering_size is not None:
@@ -1239,3 +1293,89 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__bd511ae6ed3054296246be9b4f22db1724e5b257f984289b76ea3dbeb7895c24(
+    *,
+    logging: typing.Optional[builtins.bool] = None,
+    log_group: typing.Optional[_ILogGroup_846e17a0] = None,
+    processor: typing.Optional[_IDataProcessor_682cbcf2] = None,
+    role: typing.Optional[_IRole_59af6f50] = None,
+    s3_backup: typing.Optional[typing.Union[DestinationS3BackupProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1b561016860cc7ad4535eb67c8a87c2986771bfa20db66cfb07780323fccce65(
+    *,
+    buffering_interval: typing.Optional[_Duration_070aa057] = None,
+    buffering_size: typing.Optional[_Size_7fbd4337] = None,
+    compression: typing.Optional[Compression] = None,
+    data_output_prefix: typing.Optional[builtins.str] = None,
+    encryption_key: typing.Optional[_IKey_36930160] = None,
+    error_output_prefix: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ec0614acdfc1b67db37f900a22a765af6efa4f5538cbf88bc8ad0ec4e8924f7d(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9c28be58770149688b1c550c97a6f5f8b0e585ad9440177bc45ed06cb229093f(
+    *,
+    buffering_interval: typing.Optional[_Duration_070aa057] = None,
+    buffering_size: typing.Optional[_Size_7fbd4337] = None,
+    compression: typing.Optional[Compression] = None,
+    data_output_prefix: typing.Optional[builtins.str] = None,
+    encryption_key: typing.Optional[_IKey_36930160] = None,
+    error_output_prefix: typing.Optional[builtins.str] = None,
+    bucket: typing.Optional[_IBucket_73486e29] = None,
+    logging: typing.Optional[builtins.bool] = None,
+    log_group: typing.Optional[_ILogGroup_846e17a0] = None,
+    mode: typing.Optional[BackupMode] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0edb78d0af508eb4c1e4d62d539eac5b43009d86df9c681ae7f03915b7d4f439(
+    bucket: _IBucket_73486e29,
+    *,
+    buffering_interval: typing.Optional[_Duration_070aa057] = None,
+    buffering_size: typing.Optional[_Size_7fbd4337] = None,
+    compression: typing.Optional[Compression] = None,
+    data_output_prefix: typing.Optional[builtins.str] = None,
+    encryption_key: typing.Optional[_IKey_36930160] = None,
+    error_output_prefix: typing.Optional[builtins.str] = None,
+    logging: typing.Optional[builtins.bool] = None,
+    log_group: typing.Optional[_ILogGroup_846e17a0] = None,
+    processor: typing.Optional[_IDataProcessor_682cbcf2] = None,
+    role: typing.Optional[_IRole_59af6f50] = None,
+    s3_backup: typing.Optional[typing.Union[DestinationS3BackupProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8ac9b461ea8e1276bf30a0f831affc8f191991843dbd4d749ef73e0cb1f3b898(
+    scope: _constructs_77d1e7e8.Construct,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2056623d400a1e5d9a2ddee016d09ec8fdd804c0598fdecc8719f74c760e4cc5(
+    *,
+    buffering_interval: typing.Optional[_Duration_070aa057] = None,
+    buffering_size: typing.Optional[_Size_7fbd4337] = None,
+    compression: typing.Optional[Compression] = None,
+    data_output_prefix: typing.Optional[builtins.str] = None,
+    encryption_key: typing.Optional[_IKey_36930160] = None,
+    error_output_prefix: typing.Optional[builtins.str] = None,
+    logging: typing.Optional[builtins.bool] = None,
+    log_group: typing.Optional[_ILogGroup_846e17a0] = None,
+    processor: typing.Optional[_IDataProcessor_682cbcf2] = None,
+    role: typing.Optional[_IRole_59af6f50] = None,
+    s3_backup: typing.Optional[typing.Union[DestinationS3BackupProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
