@@ -155,6 +155,19 @@ lambda_.GoFunction(self, "handler",
 )
 ```
 
+By default this construct doesn't use any Go module proxies. This is contrary to
+a standard Go installation, which would use the Google proxy by default. To
+recreate that behavior, do the following:
+
+```python
+lambda_.GoFunction(self, "GoFunction",
+    entry="app/cmd/api",
+    bundling=lambda.aws_lambda_go.BundlingOptions(
+        go_proxies=[lambda_.GoFunction.GOOGLE_GOPROXY, "direct"]
+    )
+)
+```
+
 ## Command hooks
 
 It is  possible to run additional commands by specifying the `commandHooks` prop:
@@ -251,6 +264,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from .._jsii import *
 
 from .. import (
@@ -258,6 +273,7 @@ from .. import (
     Construct as _Construct_e78e779f,
     DockerImage as _DockerImage_d5f0ad8e,
     Duration as _Duration_070aa057,
+    Size as _Size_7fbd4337,
 )
 from ..aws_codeguruprofiler import IProfilingGroup as _IProfilingGroup_418eb20c
 from ..aws_ec2 import (
@@ -302,6 +318,7 @@ from ..aws_sqs import IQueue as _IQueue_45a01ab4
         "environment": "environment",
         "forced_docker_bundling": "forcedDockerBundling",
         "go_build_flags": "goBuildFlags",
+        "go_proxies": "goProxies",
     },
 )
 class BundlingOptions:
@@ -317,6 +334,7 @@ class BundlingOptions:
         environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         forced_docker_bundling: typing.Optional[builtins.bool] = None,
         go_build_flags: typing.Optional[typing.Sequence[builtins.str]] = None,
+        go_proxies: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
         '''(experimental) Bundling options.
 
@@ -329,6 +347,7 @@ class BundlingOptions:
         :param environment: (experimental) Environment variables defined when go runs. Default: - no environment variables are defined.
         :param forced_docker_bundling: (experimental) Force bundling in a Docker container even if local bundling is possible. Default: - false
         :param go_build_flags: (experimental) List of additional flags to use while building. For example: ['ldflags "-s -w"'] Default: - none
+        :param go_proxies: (experimental) What Go proxies to use to fetch the packages involved in the build. Pass a list of proxy addresses in order, and/or the string ``'direct'`` to attempt direct access. By default this construct uses no proxies, but a standard Go install would use the Google proxy by default. To recreate that behavior, do the following:: new lambda.GoFunction(this, 'GoFunction', { entry: 'app/cmd/api', bundling: { goProxies: [lambda.GoFunction.GOOGLE_GOPROXY, 'direct'], }, }); Default: - Direct access
 
         :stability: experimental
         :exampleMetadata: infused
@@ -338,13 +357,23 @@ class BundlingOptions:
             lambda_.GoFunction(self, "handler",
                 entry="app/cmd/api",
                 bundling=lambda.aws_lambda_go.BundlingOptions(
-                    environment={
-                        "HELLO": "WORLD"
-                    }
+                    docker_image=DockerImage.from_build("/path/to/Dockerfile")
                 )
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {}
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__d3f177d2604c17ffadcf947835297768bf54b4bc71204f948d150cecdd0404b1)
+            check_type(argname="argument asset_hash", value=asset_hash, expected_type=type_hints["asset_hash"])
+            check_type(argname="argument asset_hash_type", value=asset_hash_type, expected_type=type_hints["asset_hash_type"])
+            check_type(argname="argument build_args", value=build_args, expected_type=type_hints["build_args"])
+            check_type(argname="argument cgo_enabled", value=cgo_enabled, expected_type=type_hints["cgo_enabled"])
+            check_type(argname="argument command_hooks", value=command_hooks, expected_type=type_hints["command_hooks"])
+            check_type(argname="argument docker_image", value=docker_image, expected_type=type_hints["docker_image"])
+            check_type(argname="argument environment", value=environment, expected_type=type_hints["environment"])
+            check_type(argname="argument forced_docker_bundling", value=forced_docker_bundling, expected_type=type_hints["forced_docker_bundling"])
+            check_type(argname="argument go_build_flags", value=go_build_flags, expected_type=type_hints["go_build_flags"])
+            check_type(argname="argument go_proxies", value=go_proxies, expected_type=type_hints["go_proxies"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if asset_hash is not None:
             self._values["asset_hash"] = asset_hash
         if asset_hash_type is not None:
@@ -363,6 +392,8 @@ class BundlingOptions:
             self._values["forced_docker_bundling"] = forced_docker_bundling
         if go_build_flags is not None:
             self._values["go_build_flags"] = go_build_flags
+        if go_proxies is not None:
+            self._values["go_proxies"] = go_proxies
 
     @builtins.property
     def asset_hash(self) -> typing.Optional[builtins.str]:
@@ -498,6 +529,30 @@ class BundlingOptions:
         result = self._values.get("go_build_flags")
         return typing.cast(typing.Optional[typing.List[builtins.str]], result)
 
+    @builtins.property
+    def go_proxies(self) -> typing.Optional[typing.List[builtins.str]]:
+        '''(experimental) What Go proxies to use to fetch the packages involved in the build.
+
+        Pass a list of proxy addresses in order, and/or the string ``'direct'`` to
+        attempt direct access.
+
+        By default this construct uses no proxies, but a standard Go install would
+        use the Google proxy by default. To recreate that behavior, do the following::
+
+           lambda_.GoFunction(self, "GoFunction",
+               entry="app/cmd/api",
+               bundling=lambda.aws_lambda_go.BundlingOptions(
+                   go_proxies=[lambda_.GoFunction.GOOGLE_GOPROXY, "direct"]
+               )
+           )
+
+        :default: - Direct access
+
+        :stability: experimental
+        '''
+        result = self._values.get("go_proxies")
+        return typing.cast(typing.Optional[typing.List[builtins.str]], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -525,7 +580,7 @@ class GoFunction(
         lambda_.GoFunction(self, "handler",
             entry="app/cmd/api",
             bundling=lambda.aws_lambda_go.BundlingOptions(
-                go_build_flags=["-ldflags \"-s -w\""]
+                docker_image=DockerImage.from_build("/path/to/Dockerfile")
             )
         )
     '''
@@ -536,7 +591,7 @@ class GoFunction(
         id: builtins.str,
         *,
         entry: builtins.str,
-        bundling: typing.Optional[BundlingOptions] = None,
+        bundling: typing.Optional[typing.Union[BundlingOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         module_dir: typing.Optional[builtins.str] = None,
         runtime: typing.Optional[_Runtime_932d369a] = None,
         allow_all_outbound: typing.Optional[builtins.bool] = None,
@@ -544,13 +599,14 @@ class GoFunction(
         architecture: typing.Optional[_Architecture_24056b62] = None,
         architectures: typing.Optional[typing.Sequence[_Architecture_24056b62]] = None,
         code_signing_config: typing.Optional[_ICodeSigningConfig_5d77bccf] = None,
-        current_version_options: typing.Optional[_VersionOptions_085bb455] = None,
+        current_version_options: typing.Optional[typing.Union[_VersionOptions_085bb455, typing.Dict[builtins.str, typing.Any]]] = None,
         dead_letter_queue: typing.Optional[_IQueue_45a01ab4] = None,
         dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
         dead_letter_topic: typing.Optional[_ITopic_465e36b9] = None,
         description: typing.Optional[builtins.str] = None,
         environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         environment_encryption: typing.Optional[_IKey_36930160] = None,
+        ephemeral_storage_size: typing.Optional[_Size_7fbd4337] = None,
         events: typing.Optional[typing.Sequence[_IEventSource_7914870e]] = None,
         filesystem: typing.Optional[_FileSystem_17be1f4c] = None,
         function_name: typing.Optional[builtins.str] = None,
@@ -558,7 +614,7 @@ class GoFunction(
         insights_version: typing.Optional[_LambdaInsightsVersion_2966e73b] = None,
         layers: typing.Optional[typing.Sequence[_ILayerVersion_b2b86380]] = None,
         log_retention: typing.Optional[_RetentionDays_6c560d31] = None,
-        log_retention_retry_options: typing.Optional[_LogRetentionRetryOptions_7acc40ab] = None,
+        log_retention_retry_options: typing.Optional[typing.Union[_LogRetentionRetryOptions_7acc40ab, typing.Dict[builtins.str, typing.Any]]] = None,
         log_retention_role: typing.Optional[_IRole_59af6f50] = None,
         memory_size: typing.Optional[jsii.Number] = None,
         profiling: typing.Optional[builtins.bool] = None,
@@ -570,7 +626,7 @@ class GoFunction(
         timeout: typing.Optional[_Duration_070aa057] = None,
         tracing: typing.Optional[_Tracing_b7f4a8b6] = None,
         vpc: typing.Optional[_IVpc_6d1f76c4] = None,
-        vpc_subnets: typing.Optional[_SubnetSelection_1284e62c] = None,
+        vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_1284e62c, typing.Dict[builtins.str, typing.Any]]] = None,
         max_event_age: typing.Optional[_Duration_070aa057] = None,
         on_failure: typing.Optional[_IDestination_7f253ff1] = None,
         on_success: typing.Optional[_IDestination_7f253ff1] = None,
@@ -595,6 +651,7 @@ class GoFunction(
         :param description: (experimental) A description of the function. Default: - No description.
         :param environment: (experimental) Key-value pairs that Lambda caches and makes available for your Lambda functions. Use environment variables to apply configuration changes, such as test and production environment configurations, without changing your Lambda function source code. Default: - No environment variables.
         :param environment_encryption: (experimental) The AWS KMS key that's used to encrypt your function's environment variables. Default: - AWS Lambda creates and uses an AWS managed customer master key (CMK).
+        :param ephemeral_storage_size: (experimental) The size of the function’s /tmp directory in MiB. Default: 512 MiB
         :param events: (experimental) Event sources for this function. You can also add event sources using ``addEventSource``. Default: - No event sources.
         :param filesystem: (experimental) The filesystem configuration for the lambda function. Default: - will not mount any filesystem
         :param function_name: (experimental) A name for the function. Default: - AWS CloudFormation generates a unique physical ID and uses that ID for the function's name. For more information, see Name Type.
@@ -622,6 +679,10 @@ class GoFunction(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__29d453afab962c44e4a40e5e2123c7dc14c7bb7e9dc68e4e02d73320f4108e8f)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GoFunctionProps(
             entry=entry,
             bundling=bundling,
@@ -639,6 +700,7 @@ class GoFunction(
             description=description,
             environment=environment,
             environment_encryption=environment_encryption,
+            ephemeral_storage_size=ephemeral_storage_size,
             events=events,
             filesystem=filesystem,
             function_name=function_name,
@@ -667,6 +729,15 @@ class GoFunction(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
+    @jsii.python.classproperty
+    @jsii.member(jsii_name="GOOGLE_GOPROXY")
+    def GOOGLE_GOPROXY(cls) -> builtins.str:
+        '''(experimental) The address of the Google Go proxy.
+
+        :stability: experimental
+        '''
+        return typing.cast(builtins.str, jsii.sget(cls, "GOOGLE_GOPROXY"))
+
 
 @jsii.data_type(
     jsii_type="monocdk.aws_lambda_go.GoFunctionProps",
@@ -688,6 +759,7 @@ class GoFunction(
         "description": "description",
         "environment": "environment",
         "environment_encryption": "environmentEncryption",
+        "ephemeral_storage_size": "ephemeralStorageSize",
         "events": "events",
         "filesystem": "filesystem",
         "function_name": "functionName",
@@ -727,13 +799,14 @@ class GoFunctionProps(_FunctionOptions_dc75a392):
         architecture: typing.Optional[_Architecture_24056b62] = None,
         architectures: typing.Optional[typing.Sequence[_Architecture_24056b62]] = None,
         code_signing_config: typing.Optional[_ICodeSigningConfig_5d77bccf] = None,
-        current_version_options: typing.Optional[_VersionOptions_085bb455] = None,
+        current_version_options: typing.Optional[typing.Union[_VersionOptions_085bb455, typing.Dict[builtins.str, typing.Any]]] = None,
         dead_letter_queue: typing.Optional[_IQueue_45a01ab4] = None,
         dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
         dead_letter_topic: typing.Optional[_ITopic_465e36b9] = None,
         description: typing.Optional[builtins.str] = None,
         environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         environment_encryption: typing.Optional[_IKey_36930160] = None,
+        ephemeral_storage_size: typing.Optional[_Size_7fbd4337] = None,
         events: typing.Optional[typing.Sequence[_IEventSource_7914870e]] = None,
         filesystem: typing.Optional[_FileSystem_17be1f4c] = None,
         function_name: typing.Optional[builtins.str] = None,
@@ -741,7 +814,7 @@ class GoFunctionProps(_FunctionOptions_dc75a392):
         insights_version: typing.Optional[_LambdaInsightsVersion_2966e73b] = None,
         layers: typing.Optional[typing.Sequence[_ILayerVersion_b2b86380]] = None,
         log_retention: typing.Optional[_RetentionDays_6c560d31] = None,
-        log_retention_retry_options: typing.Optional[_LogRetentionRetryOptions_7acc40ab] = None,
+        log_retention_retry_options: typing.Optional[typing.Union[_LogRetentionRetryOptions_7acc40ab, typing.Dict[builtins.str, typing.Any]]] = None,
         log_retention_role: typing.Optional[_IRole_59af6f50] = None,
         memory_size: typing.Optional[jsii.Number] = None,
         profiling: typing.Optional[builtins.bool] = None,
@@ -753,9 +826,9 @@ class GoFunctionProps(_FunctionOptions_dc75a392):
         timeout: typing.Optional[_Duration_070aa057] = None,
         tracing: typing.Optional[_Tracing_b7f4a8b6] = None,
         vpc: typing.Optional[_IVpc_6d1f76c4] = None,
-        vpc_subnets: typing.Optional[_SubnetSelection_1284e62c] = None,
+        vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_1284e62c, typing.Dict[builtins.str, typing.Any]]] = None,
         entry: builtins.str,
-        bundling: typing.Optional[BundlingOptions] = None,
+        bundling: typing.Optional[typing.Union[BundlingOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         module_dir: typing.Optional[builtins.str] = None,
         runtime: typing.Optional[_Runtime_932d369a] = None,
     ) -> None:
@@ -777,6 +850,7 @@ class GoFunctionProps(_FunctionOptions_dc75a392):
         :param description: (experimental) A description of the function. Default: - No description.
         :param environment: (experimental) Key-value pairs that Lambda caches and makes available for your Lambda functions. Use environment variables to apply configuration changes, such as test and production environment configurations, without changing your Lambda function source code. Default: - No environment variables.
         :param environment_encryption: (experimental) The AWS KMS key that's used to encrypt your function's environment variables. Default: - AWS Lambda creates and uses an AWS managed customer master key (CMK).
+        :param ephemeral_storage_size: (experimental) The size of the function’s /tmp directory in MiB. Default: 512 MiB
         :param events: (experimental) Event sources for this function. You can also add event sources using ``addEventSource``. Default: - No event sources.
         :param filesystem: (experimental) The filesystem configuration for the lambda function. Default: - will not mount any filesystem
         :param function_name: (experimental) A name for the function. Default: - AWS CloudFormation generates a unique physical ID and uses that ID for the function's name. For more information, see Name Type.
@@ -810,7 +884,7 @@ class GoFunctionProps(_FunctionOptions_dc75a392):
             lambda_.GoFunction(self, "handler",
                 entry="app/cmd/api",
                 bundling=lambda.aws_lambda_go.BundlingOptions(
-                    go_build_flags=["-ldflags \"-s -w\""]
+                    docker_image=DockerImage.from_build("/path/to/Dockerfile")
                 )
             )
         '''
@@ -822,7 +896,50 @@ class GoFunctionProps(_FunctionOptions_dc75a392):
             vpc_subnets = _SubnetSelection_1284e62c(**vpc_subnets)
         if isinstance(bundling, dict):
             bundling = BundlingOptions(**bundling)
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__10a42ba9c2fb4caa26282400e8e1daa2c37d9f7899bd7dbdb791e19e947bf84e)
+            check_type(argname="argument max_event_age", value=max_event_age, expected_type=type_hints["max_event_age"])
+            check_type(argname="argument on_failure", value=on_failure, expected_type=type_hints["on_failure"])
+            check_type(argname="argument on_success", value=on_success, expected_type=type_hints["on_success"])
+            check_type(argname="argument retry_attempts", value=retry_attempts, expected_type=type_hints["retry_attempts"])
+            check_type(argname="argument allow_all_outbound", value=allow_all_outbound, expected_type=type_hints["allow_all_outbound"])
+            check_type(argname="argument allow_public_subnet", value=allow_public_subnet, expected_type=type_hints["allow_public_subnet"])
+            check_type(argname="argument architecture", value=architecture, expected_type=type_hints["architecture"])
+            check_type(argname="argument architectures", value=architectures, expected_type=type_hints["architectures"])
+            check_type(argname="argument code_signing_config", value=code_signing_config, expected_type=type_hints["code_signing_config"])
+            check_type(argname="argument current_version_options", value=current_version_options, expected_type=type_hints["current_version_options"])
+            check_type(argname="argument dead_letter_queue", value=dead_letter_queue, expected_type=type_hints["dead_letter_queue"])
+            check_type(argname="argument dead_letter_queue_enabled", value=dead_letter_queue_enabled, expected_type=type_hints["dead_letter_queue_enabled"])
+            check_type(argname="argument dead_letter_topic", value=dead_letter_topic, expected_type=type_hints["dead_letter_topic"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
+            check_type(argname="argument environment", value=environment, expected_type=type_hints["environment"])
+            check_type(argname="argument environment_encryption", value=environment_encryption, expected_type=type_hints["environment_encryption"])
+            check_type(argname="argument ephemeral_storage_size", value=ephemeral_storage_size, expected_type=type_hints["ephemeral_storage_size"])
+            check_type(argname="argument events", value=events, expected_type=type_hints["events"])
+            check_type(argname="argument filesystem", value=filesystem, expected_type=type_hints["filesystem"])
+            check_type(argname="argument function_name", value=function_name, expected_type=type_hints["function_name"])
+            check_type(argname="argument initial_policy", value=initial_policy, expected_type=type_hints["initial_policy"])
+            check_type(argname="argument insights_version", value=insights_version, expected_type=type_hints["insights_version"])
+            check_type(argname="argument layers", value=layers, expected_type=type_hints["layers"])
+            check_type(argname="argument log_retention", value=log_retention, expected_type=type_hints["log_retention"])
+            check_type(argname="argument log_retention_retry_options", value=log_retention_retry_options, expected_type=type_hints["log_retention_retry_options"])
+            check_type(argname="argument log_retention_role", value=log_retention_role, expected_type=type_hints["log_retention_role"])
+            check_type(argname="argument memory_size", value=memory_size, expected_type=type_hints["memory_size"])
+            check_type(argname="argument profiling", value=profiling, expected_type=type_hints["profiling"])
+            check_type(argname="argument profiling_group", value=profiling_group, expected_type=type_hints["profiling_group"])
+            check_type(argname="argument reserved_concurrent_executions", value=reserved_concurrent_executions, expected_type=type_hints["reserved_concurrent_executions"])
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
+            check_type(argname="argument security_group", value=security_group, expected_type=type_hints["security_group"])
+            check_type(argname="argument security_groups", value=security_groups, expected_type=type_hints["security_groups"])
+            check_type(argname="argument timeout", value=timeout, expected_type=type_hints["timeout"])
+            check_type(argname="argument tracing", value=tracing, expected_type=type_hints["tracing"])
+            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
+            check_type(argname="argument vpc_subnets", value=vpc_subnets, expected_type=type_hints["vpc_subnets"])
+            check_type(argname="argument entry", value=entry, expected_type=type_hints["entry"])
+            check_type(argname="argument bundling", value=bundling, expected_type=type_hints["bundling"])
+            check_type(argname="argument module_dir", value=module_dir, expected_type=type_hints["module_dir"])
+            check_type(argname="argument runtime", value=runtime, expected_type=type_hints["runtime"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "entry": entry,
         }
         if max_event_age is not None:
@@ -857,6 +974,8 @@ class GoFunctionProps(_FunctionOptions_dc75a392):
             self._values["environment"] = environment
         if environment_encryption is not None:
             self._values["environment_encryption"] = environment_encryption
+        if ephemeral_storage_size is not None:
+            self._values["ephemeral_storage_size"] = ephemeral_storage_size
         if events is not None:
             self._values["events"] = events
         if filesystem is not None:
@@ -1108,6 +1227,17 @@ class GoFunctionProps(_FunctionOptions_dc75a392):
         result = self._values.get("environment_encryption")
         return typing.cast(typing.Optional[_IKey_36930160], result)
 
+    @builtins.property
+    def ephemeral_storage_size(self) -> typing.Optional[_Size_7fbd4337]:
+        '''(experimental) The size of the function’s /tmp directory in MiB.
+
+        :default: 512 MiB
+
+        :stability: experimental
+        '''
+        result = self._values.get("ephemeral_storage_size")
+        return typing.cast(typing.Optional[_Size_7fbd4337], result)
+
     @builtins.property
     def events(self) -> typing.Optional[typing.List[_IEventSource_7914870e]]:
         '''(experimental) Event sources for this function.
@@ -1573,6 +1703,10 @@ class _ICommandHooksProxy:
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__6549626e6ce4b8443d862d873cf7359f9f7255aa23e3fd91fe632c80150b7586)
+            check_type(argname="argument input_dir", value=input_dir, expected_type=type_hints["input_dir"])
+            check_type(argname="argument output_dir", value=output_dir, expected_type=type_hints["output_dir"])
         return typing.cast(typing.List[builtins.str], jsii.invoke(self, "afterBundling", [input_dir, output_dir]))
 
     @jsii.member(jsii_name="beforeBundling")
@@ -1590,6 +1724,10 @@ class _ICommandHooksProxy:
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__205cb0805b48d2b48e85655793be61548aef20096bdbf4972695a475eae9cb69)
+            check_type(argname="argument input_dir", value=input_dir, expected_type=type_hints["input_dir"])
+            check_type(argname="argument output_dir", value=output_dir, expected_type=type_hints["output_dir"])
         return typing.cast(typing.List[builtins.str], jsii.invoke(self, "beforeBundling", [input_dir, output_dir]))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
@@ -1604,3 +1742,129 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__d3f177d2604c17ffadcf947835297768bf54b4bc71204f948d150cecdd0404b1(
+    *,
+    asset_hash: typing.Optional[builtins.str] = None,
+    asset_hash_type: typing.Optional[_AssetHashType_49193809] = None,
+    build_args: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    cgo_enabled: typing.Optional[builtins.bool] = None,
+    command_hooks: typing.Optional[ICommandHooks] = None,
+    docker_image: typing.Optional[_DockerImage_d5f0ad8e] = None,
+    environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    forced_docker_bundling: typing.Optional[builtins.bool] = None,
+    go_build_flags: typing.Optional[typing.Sequence[builtins.str]] = None,
+    go_proxies: typing.Optional[typing.Sequence[builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__29d453afab962c44e4a40e5e2123c7dc14c7bb7e9dc68e4e02d73320f4108e8f(
+    scope: _Construct_e78e779f,
+    id: builtins.str,
+    *,
+    entry: builtins.str,
+    bundling: typing.Optional[typing.Union[BundlingOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+    module_dir: typing.Optional[builtins.str] = None,
+    runtime: typing.Optional[_Runtime_932d369a] = None,
+    allow_all_outbound: typing.Optional[builtins.bool] = None,
+    allow_public_subnet: typing.Optional[builtins.bool] = None,
+    architecture: typing.Optional[_Architecture_24056b62] = None,
+    architectures: typing.Optional[typing.Sequence[_Architecture_24056b62]] = None,
+    code_signing_config: typing.Optional[_ICodeSigningConfig_5d77bccf] = None,
+    current_version_options: typing.Optional[typing.Union[_VersionOptions_085bb455, typing.Dict[builtins.str, typing.Any]]] = None,
+    dead_letter_queue: typing.Optional[_IQueue_45a01ab4] = None,
+    dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
+    dead_letter_topic: typing.Optional[_ITopic_465e36b9] = None,
+    description: typing.Optional[builtins.str] = None,
+    environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    environment_encryption: typing.Optional[_IKey_36930160] = None,
+    ephemeral_storage_size: typing.Optional[_Size_7fbd4337] = None,
+    events: typing.Optional[typing.Sequence[_IEventSource_7914870e]] = None,
+    filesystem: typing.Optional[_FileSystem_17be1f4c] = None,
+    function_name: typing.Optional[builtins.str] = None,
+    initial_policy: typing.Optional[typing.Sequence[_PolicyStatement_296fe8a3]] = None,
+    insights_version: typing.Optional[_LambdaInsightsVersion_2966e73b] = None,
+    layers: typing.Optional[typing.Sequence[_ILayerVersion_b2b86380]] = None,
+    log_retention: typing.Optional[_RetentionDays_6c560d31] = None,
+    log_retention_retry_options: typing.Optional[typing.Union[_LogRetentionRetryOptions_7acc40ab, typing.Dict[builtins.str, typing.Any]]] = None,
+    log_retention_role: typing.Optional[_IRole_59af6f50] = None,
+    memory_size: typing.Optional[jsii.Number] = None,
+    profiling: typing.Optional[builtins.bool] = None,
+    profiling_group: typing.Optional[_IProfilingGroup_418eb20c] = None,
+    reserved_concurrent_executions: typing.Optional[jsii.Number] = None,
+    role: typing.Optional[_IRole_59af6f50] = None,
+    security_group: typing.Optional[_ISecurityGroup_cdbba9d3] = None,
+    security_groups: typing.Optional[typing.Sequence[_ISecurityGroup_cdbba9d3]] = None,
+    timeout: typing.Optional[_Duration_070aa057] = None,
+    tracing: typing.Optional[_Tracing_b7f4a8b6] = None,
+    vpc: typing.Optional[_IVpc_6d1f76c4] = None,
+    vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_1284e62c, typing.Dict[builtins.str, typing.Any]]] = None,
+    max_event_age: typing.Optional[_Duration_070aa057] = None,
+    on_failure: typing.Optional[_IDestination_7f253ff1] = None,
+    on_success: typing.Optional[_IDestination_7f253ff1] = None,
+    retry_attempts: typing.Optional[jsii.Number] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__10a42ba9c2fb4caa26282400e8e1daa2c37d9f7899bd7dbdb791e19e947bf84e(
+    *,
+    max_event_age: typing.Optional[_Duration_070aa057] = None,
+    on_failure: typing.Optional[_IDestination_7f253ff1] = None,
+    on_success: typing.Optional[_IDestination_7f253ff1] = None,
+    retry_attempts: typing.Optional[jsii.Number] = None,
+    allow_all_outbound: typing.Optional[builtins.bool] = None,
+    allow_public_subnet: typing.Optional[builtins.bool] = None,
+    architecture: typing.Optional[_Architecture_24056b62] = None,
+    architectures: typing.Optional[typing.Sequence[_Architecture_24056b62]] = None,
+    code_signing_config: typing.Optional[_ICodeSigningConfig_5d77bccf] = None,
+    current_version_options: typing.Optional[typing.Union[_VersionOptions_085bb455, typing.Dict[builtins.str, typing.Any]]] = None,
+    dead_letter_queue: typing.Optional[_IQueue_45a01ab4] = None,
+    dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
+    dead_letter_topic: typing.Optional[_ITopic_465e36b9] = None,
+    description: typing.Optional[builtins.str] = None,
+    environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    environment_encryption: typing.Optional[_IKey_36930160] = None,
+    ephemeral_storage_size: typing.Optional[_Size_7fbd4337] = None,
+    events: typing.Optional[typing.Sequence[_IEventSource_7914870e]] = None,
+    filesystem: typing.Optional[_FileSystem_17be1f4c] = None,
+    function_name: typing.Optional[builtins.str] = None,
+    initial_policy: typing.Optional[typing.Sequence[_PolicyStatement_296fe8a3]] = None,
+    insights_version: typing.Optional[_LambdaInsightsVersion_2966e73b] = None,
+    layers: typing.Optional[typing.Sequence[_ILayerVersion_b2b86380]] = None,
+    log_retention: typing.Optional[_RetentionDays_6c560d31] = None,
+    log_retention_retry_options: typing.Optional[typing.Union[_LogRetentionRetryOptions_7acc40ab, typing.Dict[builtins.str, typing.Any]]] = None,
+    log_retention_role: typing.Optional[_IRole_59af6f50] = None,
+    memory_size: typing.Optional[jsii.Number] = None,
+    profiling: typing.Optional[builtins.bool] = None,
+    profiling_group: typing.Optional[_IProfilingGroup_418eb20c] = None,
+    reserved_concurrent_executions: typing.Optional[jsii.Number] = None,
+    role: typing.Optional[_IRole_59af6f50] = None,
+    security_group: typing.Optional[_ISecurityGroup_cdbba9d3] = None,
+    security_groups: typing.Optional[typing.Sequence[_ISecurityGroup_cdbba9d3]] = None,
+    timeout: typing.Optional[_Duration_070aa057] = None,
+    tracing: typing.Optional[_Tracing_b7f4a8b6] = None,
+    vpc: typing.Optional[_IVpc_6d1f76c4] = None,
+    vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_1284e62c, typing.Dict[builtins.str, typing.Any]]] = None,
+    entry: builtins.str,
+    bundling: typing.Optional[typing.Union[BundlingOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+    module_dir: typing.Optional[builtins.str] = None,
+    runtime: typing.Optional[_Runtime_932d369a] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6549626e6ce4b8443d862d873cf7359f9f7255aa23e3fd91fe632c80150b7586(
+    input_dir: builtins.str,
+    output_dir: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__205cb0805b48d2b48e85655793be61548aef20096bdbf4972695a475eae9cb69(
+    input_dir: builtins.str,
+    output_dir: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
