@@ -131,7 +131,8 @@ s3deploy.BucketDeployment(self, "DeployMeWithoutDeletingFilesOnDestination",
 )
 ```
 
-This option also enables you to specify multiple bucket deployments for the same destination bucket & prefix,
+This option also enables you to
+multiple bucket deployments for the same destination bucket & prefix,
 each with its own characteristics. For example, you can set different cache-control headers
 based on file extensions:
 
@@ -255,14 +256,19 @@ s3deploy.BucketDeployment(self, "DeployWithInvalidation",
 )
 ```
 
-## Memory Limit
+## Size Limits
 
 The default memory limit for the deployment resource is 128MiB. If you need to
-copy larger files, you can use the `memoryLimit` configuration to specify the
+copy larger files, you can use the `memoryLimit` configuration to increase the
 size of the AWS Lambda resource handler.
 
-> NOTE: a new AWS Lambda handler will be created in your stack for each memory
-> limit configuration.
+The default ephemeral storage size for the deployment resource is 512MiB. If you
+need to upload larger files, you may hit this limit. You can use the
+`ephemeralStorageSize` configuration to increase the storage size of the AWS Lambda
+resource handler.
+
+> NOTE: a new AWS Lambda handler will be created in your stack for each combination
+> of memory and storage size.
 
 ## EFS Support
 
@@ -337,11 +343,11 @@ substituting it when its deployed to the destination with the actual value.
 
 ## Development
 
-The custom resource is implemented in Python 3.6 in order to be able to leverage
+The custom resource is implemented in Python 3.7 in order to be able to leverage
 the AWS CLI for "aws s3 sync". The code is under [`lib/lambda`](https://github.com/aws/aws-cdk/tree/master/packages/%40aws-cdk/aws-s3-deployment/lib/lambda) and
 unit tests are under [`test/lambda`](https://github.com/aws/aws-cdk/tree/master/packages/%40aws-cdk/aws-s3-deployment/test/lambda).
 
-This package requires Python 3.6 during build time in order to create the custom
+This package requires Python 3.7 during build time in order to create the custom
 resource Lambda bundle and test it. It also relies on a few bash scripts, so
 might be tricky to build on Windows.
 
@@ -359,9 +365,11 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from .._jsii import *
 
-import constructs
+import constructs as _constructs_77d1e7e8
 from .. import (
     AssetHashType as _AssetHashType_49193809,
     BundlingOptions as _BundlingOptions_ab115a99,
@@ -369,6 +377,7 @@ from .. import (
     Duration as _Duration_070aa057,
     Expiration as _Expiration_505df041,
     IgnoreMode as _IgnoreMode_31d8bf46,
+    Size as _Size_7fbd4337,
     SymlinkFollowMode as _SymlinkFollowMode_abf4527a,
 )
 from ..assets import FollowMode as _FollowMode_98b05cc5
@@ -412,7 +421,7 @@ class BucketDeployment(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         destination_bucket: _IBucket_73486e29,
@@ -426,12 +435,13 @@ class BucketDeployment(
         destination_key_prefix: typing.Optional[builtins.str] = None,
         distribution: typing.Optional[_IDistribution_685deca5] = None,
         distribution_paths: typing.Optional[typing.Sequence[builtins.str]] = None,
+        ephemeral_storage_size: typing.Optional[_Size_7fbd4337] = None,
         exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
         expires: typing.Optional[_Expiration_505df041] = None,
         include: typing.Optional[typing.Sequence[builtins.str]] = None,
         log_retention: typing.Optional[_RetentionDays_6c560d31] = None,
         memory_limit: typing.Optional[jsii.Number] = None,
-        metadata: typing.Optional["UserDefinedObjectMetadata"] = None,
+        metadata: typing.Optional[typing.Union["UserDefinedObjectMetadata", typing.Dict[builtins.str, typing.Any]]] = None,
         prune: typing.Optional[builtins.bool] = None,
         retain_on_delete: typing.Optional[builtins.bool] = None,
         role: typing.Optional[_IRole_59af6f50] = None,
@@ -441,7 +451,7 @@ class BucketDeployment(
         storage_class: typing.Optional["StorageClass"] = None,
         use_efs: typing.Optional[builtins.bool] = None,
         vpc: typing.Optional[_IVpc_6d1f76c4] = None,
-        vpc_subnets: typing.Optional[_SubnetSelection_1284e62c] = None,
+        vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_1284e62c, typing.Dict[builtins.str, typing.Any]]] = None,
         website_redirect_location: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -458,6 +468,7 @@ class BucketDeployment(
         :param destination_key_prefix: (experimental) Key prefix in the destination bucket. Must be <=104 characters Default: "/" (unzip to root of the destination bucket)
         :param distribution: (experimental) The CloudFront distribution using the destination bucket as an origin. Files in the distribution's edge caches will be invalidated after files are uploaded to the destination bucket. Default: - No invalidation occurs
         :param distribution_paths: (experimental) The file paths to invalidate in the CloudFront distribution. Default: - All files under the destination bucket key prefix will be invalidated.
+        :param ephemeral_storage_size: (experimental) The size of the AWS Lambda function’s /tmp directory in MiB. Default: 512 MiB
         :param exclude: (experimental) If this is set, matching files or objects will be excluded from the deployment's sync command. This can be used to exclude a file from being pruned in the destination bucket. If you want to just exclude files from the deployment package (which excludes these files evaluated when invalidating the asset), you should leverage the ``exclude`` property of ``AssetOptions`` when defining your source. Default: - No exclude filters are used
         :param expires: (experimental) System-defined expires metadata to be set on all objects in the deployment. Default: - The objects in the distribution will not expire.
         :param include: (experimental) If this is set, matching files or objects will be included with the deployment's sync command. Since all files from the deployment package are included by default, this property is usually leveraged alongside an ``exclude`` filter. Default: - No include filters are used and all files are included with the sync command
@@ -478,6 +489,10 @@ class BucketDeployment(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__2519dc762059e78f5c6ab9d6433df4eea856201ce5a758ef60a73609d85966d4)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = BucketDeploymentProps(
             destination_bucket=destination_bucket,
             sources=sources,
@@ -490,6 +505,7 @@ class BucketDeployment(
             destination_key_prefix=destination_key_prefix,
             distribution=distribution,
             distribution_paths=distribution_paths,
+            ephemeral_storage_size=ephemeral_storage_size,
             exclude=exclude,
             expires=expires,
             include=include,
@@ -511,7 +527,7 @@ class BucketDeployment(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="deployedBucket")
     def deployed_bucket(self) -> _IBucket_73486e29:
         '''(experimental) The bucket after the deployment.
@@ -542,6 +558,7 @@ class BucketDeployment(
         "destination_key_prefix": "destinationKeyPrefix",
         "distribution": "distribution",
         "distribution_paths": "distributionPaths",
+        "ephemeral_storage_size": "ephemeralStorageSize",
         "exclude": "exclude",
         "expires": "expires",
         "include": "include",
@@ -576,12 +593,13 @@ class BucketDeploymentProps:
         destination_key_prefix: typing.Optional[builtins.str] = None,
         distribution: typing.Optional[_IDistribution_685deca5] = None,
         distribution_paths: typing.Optional[typing.Sequence[builtins.str]] = None,
+        ephemeral_storage_size: typing.Optional[_Size_7fbd4337] = None,
         exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
         expires: typing.Optional[_Expiration_505df041] = None,
         include: typing.Optional[typing.Sequence[builtins.str]] = None,
         log_retention: typing.Optional[_RetentionDays_6c560d31] = None,
         memory_limit: typing.Optional[jsii.Number] = None,
-        metadata: typing.Optional["UserDefinedObjectMetadata"] = None,
+        metadata: typing.Optional[typing.Union["UserDefinedObjectMetadata", typing.Dict[builtins.str, typing.Any]]] = None,
         prune: typing.Optional[builtins.bool] = None,
         retain_on_delete: typing.Optional[builtins.bool] = None,
         role: typing.Optional[_IRole_59af6f50] = None,
@@ -591,7 +609,7 @@ class BucketDeploymentProps:
         storage_class: typing.Optional["StorageClass"] = None,
         use_efs: typing.Optional[builtins.bool] = None,
         vpc: typing.Optional[_IVpc_6d1f76c4] = None,
-        vpc_subnets: typing.Optional[_SubnetSelection_1284e62c] = None,
+        vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_1284e62c, typing.Dict[builtins.str, typing.Any]]] = None,
         website_redirect_location: typing.Optional[builtins.str] = None,
     ) -> None:
         '''(experimental) Properties for ``BucketDeployment``.
@@ -607,6 +625,7 @@ class BucketDeploymentProps:
         :param destination_key_prefix: (experimental) Key prefix in the destination bucket. Must be <=104 characters Default: "/" (unzip to root of the destination bucket)
         :param distribution: (experimental) The CloudFront distribution using the destination bucket as an origin. Files in the distribution's edge caches will be invalidated after files are uploaded to the destination bucket. Default: - No invalidation occurs
         :param distribution_paths: (experimental) The file paths to invalidate in the CloudFront distribution. Default: - All files under the destination bucket key prefix will be invalidated.
+        :param ephemeral_storage_size: (experimental) The size of the AWS Lambda function’s /tmp directory in MiB. Default: 512 MiB
         :param exclude: (experimental) If this is set, matching files or objects will be excluded from the deployment's sync command. This can be used to exclude a file from being pruned in the destination bucket. If you want to just exclude files from the deployment package (which excludes these files evaluated when invalidating the asset), you should leverage the ``exclude`` property of ``AssetOptions`` when defining your source. Default: - No exclude filters are used
         :param expires: (experimental) System-defined expires metadata to be set on all objects in the deployment. Default: - The objects in the distribution will not expire.
         :param include: (experimental) If this is set, matching files or objects will be included with the deployment's sync command. Since all files from the deployment package are included by default, this property is usually leveraged alongside an ``exclude`` filter. Default: - No include filters are used and all files are included with the sync command
@@ -647,7 +666,38 @@ class BucketDeploymentProps:
             metadata = UserDefinedObjectMetadata(**metadata)
         if isinstance(vpc_subnets, dict):
             vpc_subnets = _SubnetSelection_1284e62c(**vpc_subnets)
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__04fcc85683ab0737268fde9e035654ab4a79233abf0a8437652bc4259ca98824)
+            check_type(argname="argument destination_bucket", value=destination_bucket, expected_type=type_hints["destination_bucket"])
+            check_type(argname="argument sources", value=sources, expected_type=type_hints["sources"])
+            check_type(argname="argument access_control", value=access_control, expected_type=type_hints["access_control"])
+            check_type(argname="argument cache_control", value=cache_control, expected_type=type_hints["cache_control"])
+            check_type(argname="argument content_disposition", value=content_disposition, expected_type=type_hints["content_disposition"])
+            check_type(argname="argument content_encoding", value=content_encoding, expected_type=type_hints["content_encoding"])
+            check_type(argname="argument content_language", value=content_language, expected_type=type_hints["content_language"])
+            check_type(argname="argument content_type", value=content_type, expected_type=type_hints["content_type"])
+            check_type(argname="argument destination_key_prefix", value=destination_key_prefix, expected_type=type_hints["destination_key_prefix"])
+            check_type(argname="argument distribution", value=distribution, expected_type=type_hints["distribution"])
+            check_type(argname="argument distribution_paths", value=distribution_paths, expected_type=type_hints["distribution_paths"])
+            check_type(argname="argument ephemeral_storage_size", value=ephemeral_storage_size, expected_type=type_hints["ephemeral_storage_size"])
+            check_type(argname="argument exclude", value=exclude, expected_type=type_hints["exclude"])
+            check_type(argname="argument expires", value=expires, expected_type=type_hints["expires"])
+            check_type(argname="argument include", value=include, expected_type=type_hints["include"])
+            check_type(argname="argument log_retention", value=log_retention, expected_type=type_hints["log_retention"])
+            check_type(argname="argument memory_limit", value=memory_limit, expected_type=type_hints["memory_limit"])
+            check_type(argname="argument metadata", value=metadata, expected_type=type_hints["metadata"])
+            check_type(argname="argument prune", value=prune, expected_type=type_hints["prune"])
+            check_type(argname="argument retain_on_delete", value=retain_on_delete, expected_type=type_hints["retain_on_delete"])
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
+            check_type(argname="argument server_side_encryption", value=server_side_encryption, expected_type=type_hints["server_side_encryption"])
+            check_type(argname="argument server_side_encryption_aws_kms_key_id", value=server_side_encryption_aws_kms_key_id, expected_type=type_hints["server_side_encryption_aws_kms_key_id"])
+            check_type(argname="argument server_side_encryption_customer_algorithm", value=server_side_encryption_customer_algorithm, expected_type=type_hints["server_side_encryption_customer_algorithm"])
+            check_type(argname="argument storage_class", value=storage_class, expected_type=type_hints["storage_class"])
+            check_type(argname="argument use_efs", value=use_efs, expected_type=type_hints["use_efs"])
+            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
+            check_type(argname="argument vpc_subnets", value=vpc_subnets, expected_type=type_hints["vpc_subnets"])
+            check_type(argname="argument website_redirect_location", value=website_redirect_location, expected_type=type_hints["website_redirect_location"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "destination_bucket": destination_bucket,
             "sources": sources,
         }
@@ -669,6 +719,8 @@ class BucketDeploymentProps:
             self._values["distribution"] = distribution
         if distribution_paths is not None:
             self._values["distribution_paths"] = distribution_paths
+        if ephemeral_storage_size is not None:
+            self._values["ephemeral_storage_size"] = ephemeral_storage_size
         if exclude is not None:
             self._values["exclude"] = exclude
         if expires is not None:
@@ -834,6 +886,17 @@ class BucketDeploymentProps:
         result = self._values.get("distribution_paths")
         return typing.cast(typing.Optional[typing.List[builtins.str]], result)
 
+    @builtins.property
+    def ephemeral_storage_size(self) -> typing.Optional[_Size_7fbd4337]:
+        '''(experimental) The size of the AWS Lambda function’s /tmp directory in MiB.
+
+        :default: 512 MiB
+
+        :stability: experimental
+        '''
+        result = self._values.get("ephemeral_storage_size")
+        return typing.cast(typing.Optional[_Size_7fbd4337], result)
+
     @builtins.property
     def exclude(self) -> typing.Optional[typing.List[builtins.str]]:
         '''(experimental) If this is set, matching files or objects will be excluded from the deployment's sync command.
@@ -1099,7 +1162,7 @@ class CacheControl(
         )
     '''
 
-    @jsii.member(jsii_name="fromString") # type: ignore[misc]
+    @jsii.member(jsii_name="fromString")
     @builtins.classmethod
     def from_string(cls, s: builtins.str) -> "CacheControl":
         '''(experimental) Constructs a custom cache control key from the literal value.
@@ -1108,9 +1171,12 @@ class CacheControl(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__63ac57a06200a61758095b95c015c6a89dd2c2d0f1031625cc464895d885f244)
+            check_type(argname="argument s", value=s, expected_type=type_hints["s"])
         return typing.cast("CacheControl", jsii.sinvoke(cls, "fromString", [s]))
 
-    @jsii.member(jsii_name="maxAge") # type: ignore[misc]
+    @jsii.member(jsii_name="maxAge")
     @builtins.classmethod
     def max_age(cls, t: _Duration_070aa057) -> "CacheControl":
         '''(experimental) Sets 'max-age='.
@@ -1119,9 +1185,12 @@ class CacheControl(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__6e380cb78dc6be9797c938d16dfd2c73a4567a913ef68de792bd7d4894aa2335)
+            check_type(argname="argument t", value=t, expected_type=type_hints["t"])
         return typing.cast("CacheControl", jsii.sinvoke(cls, "maxAge", [t]))
 
-    @jsii.member(jsii_name="mustRevalidate") # type: ignore[misc]
+    @jsii.member(jsii_name="mustRevalidate")
     @builtins.classmethod
     def must_revalidate(cls) -> "CacheControl":
         '''(experimental) Sets 'must-revalidate'.
@@ -1130,7 +1199,7 @@ class CacheControl(
         '''
         return typing.cast("CacheControl", jsii.sinvoke(cls, "mustRevalidate", []))
 
-    @jsii.member(jsii_name="noCache") # type: ignore[misc]
+    @jsii.member(jsii_name="noCache")
     @builtins.classmethod
     def no_cache(cls) -> "CacheControl":
         '''(experimental) Sets 'no-cache'.
@@ -1139,7 +1208,7 @@ class CacheControl(
         '''
         return typing.cast("CacheControl", jsii.sinvoke(cls, "noCache", []))
 
-    @jsii.member(jsii_name="noTransform") # type: ignore[misc]
+    @jsii.member(jsii_name="noTransform")
     @builtins.classmethod
     def no_transform(cls) -> "CacheControl":
         '''(experimental) Sets 'no-transform'.
@@ -1148,7 +1217,7 @@ class CacheControl(
         '''
         return typing.cast("CacheControl", jsii.sinvoke(cls, "noTransform", []))
 
-    @jsii.member(jsii_name="proxyRevalidate") # type: ignore[misc]
+    @jsii.member(jsii_name="proxyRevalidate")
     @builtins.classmethod
     def proxy_revalidate(cls) -> "CacheControl":
         '''(experimental) Sets 'proxy-revalidate'.
@@ -1157,7 +1226,7 @@ class CacheControl(
         '''
         return typing.cast("CacheControl", jsii.sinvoke(cls, "proxyRevalidate", []))
 
-    @jsii.member(jsii_name="setPrivate") # type: ignore[misc]
+    @jsii.member(jsii_name="setPrivate")
     @builtins.classmethod
     def set_private(cls) -> "CacheControl":
         '''(experimental) Sets 'private'.
@@ -1166,7 +1235,7 @@ class CacheControl(
         '''
         return typing.cast("CacheControl", jsii.sinvoke(cls, "setPrivate", []))
 
-    @jsii.member(jsii_name="setPublic") # type: ignore[misc]
+    @jsii.member(jsii_name="setPublic")
     @builtins.classmethod
     def set_public(cls) -> "CacheControl":
         '''(experimental) Sets 'public'.
@@ -1175,7 +1244,7 @@ class CacheControl(
         '''
         return typing.cast("CacheControl", jsii.sinvoke(cls, "setPublic", []))
 
-    @jsii.member(jsii_name="sMaxAge") # type: ignore[misc]
+    @jsii.member(jsii_name="sMaxAge")
     @builtins.classmethod
     def s_max_age(cls, t: _Duration_070aa057) -> "CacheControl":
         '''(experimental) Sets 's-maxage='.
@@ -1184,9 +1253,12 @@ class CacheControl(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__2c40c18bdc0f9191795b33374a3b1056cd977cf7614535d0deaddfe94ccecfe2)
+            check_type(argname="argument t", value=t, expected_type=type_hints["t"])
         return typing.cast("CacheControl", jsii.sinvoke(cls, "sMaxAge", [t]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="value")
     def value(self) -> typing.Any:
         '''(experimental) The raw cache control setting.
@@ -1223,7 +1295,10 @@ class DeploymentSourceContext:
                 handler_role=role
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__5d54cbf804b63cfb2ffd1e2c4038a59fe3f522477e771c77cad74a7f0a4492bb)
+            check_type(argname="argument handler_role", value=handler_role, expected_type=type_hints["handler_role"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "handler_role": handler_role,
         }
 
@@ -1272,7 +1347,7 @@ class Expires(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_s3_deployment.Expi
         expires = s3_deployment.Expires.after(duration)
     '''
 
-    @jsii.member(jsii_name="after") # type: ignore[misc]
+    @jsii.member(jsii_name="after")
     @builtins.classmethod
     def after(cls, t: _Duration_070aa057) -> "Expires":
         '''(deprecated) Expire once the specified duration has passed since deployment time.
@@ -1281,9 +1356,12 @@ class Expires(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_s3_deployment.Expi
 
         :stability: deprecated
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__df948c6d3f1075ea8cbd38cfea4f31ce644f2052efc011e24c399d607f355fc8)
+            check_type(argname="argument t", value=t, expected_type=type_hints["t"])
         return typing.cast("Expires", jsii.sinvoke(cls, "after", [t]))
 
-    @jsii.member(jsii_name="atDate") # type: ignore[misc]
+    @jsii.member(jsii_name="atDate")
     @builtins.classmethod
     def at_date(cls, d: datetime.datetime) -> "Expires":
         '''(deprecated) Expire at the specified date.
@@ -1292,9 +1370,12 @@ class Expires(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_s3_deployment.Expi
 
         :stability: deprecated
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__e606be861e3c298a117f64775c8468e1daaeaa2a690e91e9b2f66a68265d6d79)
+            check_type(argname="argument d", value=d, expected_type=type_hints["d"])
         return typing.cast("Expires", jsii.sinvoke(cls, "atDate", [d]))
 
-    @jsii.member(jsii_name="atTimestamp") # type: ignore[misc]
+    @jsii.member(jsii_name="atTimestamp")
     @builtins.classmethod
     def at_timestamp(cls, t: jsii.Number) -> "Expires":
         '''(deprecated) Expire at the specified timestamp.
@@ -1303,9 +1384,12 @@ class Expires(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_s3_deployment.Expi
 
         :stability: deprecated
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__7797f22c13870d77c891043d953f51097c305b01b94ccded2ee925dd48fe3815)
+            check_type(argname="argument t", value=t, expected_type=type_hints["t"])
         return typing.cast("Expires", jsii.sinvoke(cls, "atTimestamp", [t]))
 
-    @jsii.member(jsii_name="fromString") # type: ignore[misc]
+    @jsii.member(jsii_name="fromString")
     @builtins.classmethod
     def from_string(cls, s: builtins.str) -> "Expires":
         '''(deprecated) Create an expiration date from a raw date string.
@@ -1314,9 +1398,12 @@ class Expires(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_s3_deployment.Expi
 
         :stability: deprecated
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__d1d19dbd8113e684f139b09164d515078cb3ed1b76d6a5b727ba020391deff61)
+            check_type(argname="argument s", value=s, expected_type=type_hints["s"])
         return typing.cast("Expires", jsii.sinvoke(cls, "fromString", [s]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="value")
     def value(self) -> typing.Any:
         '''(deprecated) The raw expiration date expression.
@@ -1372,6 +1459,9 @@ class _ISourceProxy:
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__34bd2c4be800507ae42bfba48dd15c222308216cdfa18eecba877d068f98c693)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
         context = DeploymentSourceContext(handler_role=handler_role)
 
         return typing.cast("SourceConfig", jsii.invoke(self, "bind", [scope, context]))
@@ -1456,7 +1546,7 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_s3_deployment.Sourc
         })
     '''
 
-    @jsii.member(jsii_name="asset") # type: ignore[misc]
+    @jsii.member(jsii_name="asset")
     @builtins.classmethod
     def asset(
         cls,
@@ -1470,7 +1560,7 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_s3_deployment.Sourc
         follow_symlinks: typing.Optional[_SymlinkFollowMode_abf4527a] = None,
         asset_hash: typing.Optional[builtins.str] = None,
         asset_hash_type: typing.Optional[_AssetHashType_49193809] = None,
-        bundling: typing.Optional[_BundlingOptions_ab115a99] = None,
+        bundling: typing.Optional[typing.Union[_BundlingOptions_ab115a99, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> ISource:
         '''(experimental) Uses a local asset as the deployment source.
 
@@ -1490,6 +1580,9 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_s3_deployment.Sourc
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__d0e3f5e3756c8d34bb7fadf7ccdeaeb9aa74917649593c3b793baf9cd396a818)
+            check_type(argname="argument path", value=path, expected_type=type_hints["path"])
         options = _AssetOptions_bd2996da(
             readers=readers,
             source_hash=source_hash,
@@ -1504,7 +1597,7 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_s3_deployment.Sourc
 
         return typing.cast(ISource, jsii.sinvoke(cls, "asset", [path, options]))
 
-    @jsii.member(jsii_name="bucket") # type: ignore[misc]
+    @jsii.member(jsii_name="bucket")
     @builtins.classmethod
     def bucket(cls, bucket: _IBucket_73486e29, zip_object_key: builtins.str) -> ISource:
         '''(experimental) Uses a .zip file stored in an S3 bucket as the source for the destination bucket contents.
@@ -1516,9 +1609,13 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_s3_deployment.Sourc
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__c119728ece64deaffc61f6de12dff79ec0b07514b449485478ba54f87952e04a)
+            check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
+            check_type(argname="argument zip_object_key", value=zip_object_key, expected_type=type_hints["zip_object_key"])
         return typing.cast(ISource, jsii.sinvoke(cls, "bucket", [bucket, zip_object_key]))
 
-    @jsii.member(jsii_name="data") # type: ignore[misc]
+    @jsii.member(jsii_name="data")
     @builtins.classmethod
     def data(cls, object_key: builtins.str, data: builtins.str) -> ISource:
         '''(experimental) Deploys an object with the specified string contents into the bucket.
@@ -1534,9 +1631,13 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_s3_deployment.Sourc
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__130a872dd9f4cdb85f52703bfd9fd24c41640fccfb6faace0689610ecc0e29e8)
+            check_type(argname="argument object_key", value=object_key, expected_type=type_hints["object_key"])
+            check_type(argname="argument data", value=data, expected_type=type_hints["data"])
         return typing.cast(ISource, jsii.sinvoke(cls, "data", [object_key, data]))
 
-    @jsii.member(jsii_name="jsonData") # type: ignore[misc]
+    @jsii.member(jsii_name="jsonData")
     @builtins.classmethod
     def json_data(cls, object_key: builtins.str, obj: typing.Any) -> ISource:
         '''(experimental) Deploys an object with the specified JSON object into the bucket.
@@ -1550,6 +1651,10 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_s3_deployment.Sourc
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__4ea12f1ef8b32f7ae9db75283fc5bd8f2edf28e6b1b2d855f685233dfe3bc40c)
+            check_type(argname="argument object_key", value=object_key, expected_type=type_hints["object_key"])
+            check_type(argname="argument obj", value=obj, expected_type=type_hints["obj"])
         return typing.cast(ISource, jsii.sinvoke(cls, "jsonData", [object_key, obj]))
 
 
@@ -1599,7 +1704,12 @@ class SourceConfig:
                 }
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__a51cfd65f7a1ece82f3b56d790bdbaa329fb34b61c2b856ca6066bd0438eaae5)
+            check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
+            check_type(argname="argument zip_object_key", value=zip_object_key, expected_type=type_hints["zip_object_key"])
+            check_type(argname="argument markers", value=markers, expected_type=type_hints["markers"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "bucket": bucket,
             "zip_object_key": zip_object_key,
         }
@@ -1757,7 +1867,7 @@ class UserDefinedObjectMetadata:
                 access_control=s3.BucketAccessControl.BUCKET_OWNER_FULL_CONTROL
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -1786,3 +1896,178 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__2519dc762059e78f5c6ab9d6433df4eea856201ce5a758ef60a73609d85966d4(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    destination_bucket: _IBucket_73486e29,
+    sources: typing.Sequence[ISource],
+    access_control: typing.Optional[_BucketAccessControl_a8cb5bce] = None,
+    cache_control: typing.Optional[typing.Sequence[CacheControl]] = None,
+    content_disposition: typing.Optional[builtins.str] = None,
+    content_encoding: typing.Optional[builtins.str] = None,
+    content_language: typing.Optional[builtins.str] = None,
+    content_type: typing.Optional[builtins.str] = None,
+    destination_key_prefix: typing.Optional[builtins.str] = None,
+    distribution: typing.Optional[_IDistribution_685deca5] = None,
+    distribution_paths: typing.Optional[typing.Sequence[builtins.str]] = None,
+    ephemeral_storage_size: typing.Optional[_Size_7fbd4337] = None,
+    exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+    expires: typing.Optional[_Expiration_505df041] = None,
+    include: typing.Optional[typing.Sequence[builtins.str]] = None,
+    log_retention: typing.Optional[_RetentionDays_6c560d31] = None,
+    memory_limit: typing.Optional[jsii.Number] = None,
+    metadata: typing.Optional[typing.Union[UserDefinedObjectMetadata, typing.Dict[builtins.str, typing.Any]]] = None,
+    prune: typing.Optional[builtins.bool] = None,
+    retain_on_delete: typing.Optional[builtins.bool] = None,
+    role: typing.Optional[_IRole_59af6f50] = None,
+    server_side_encryption: typing.Optional[ServerSideEncryption] = None,
+    server_side_encryption_aws_kms_key_id: typing.Optional[builtins.str] = None,
+    server_side_encryption_customer_algorithm: typing.Optional[builtins.str] = None,
+    storage_class: typing.Optional[StorageClass] = None,
+    use_efs: typing.Optional[builtins.bool] = None,
+    vpc: typing.Optional[_IVpc_6d1f76c4] = None,
+    vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_1284e62c, typing.Dict[builtins.str, typing.Any]]] = None,
+    website_redirect_location: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__04fcc85683ab0737268fde9e035654ab4a79233abf0a8437652bc4259ca98824(
+    *,
+    destination_bucket: _IBucket_73486e29,
+    sources: typing.Sequence[ISource],
+    access_control: typing.Optional[_BucketAccessControl_a8cb5bce] = None,
+    cache_control: typing.Optional[typing.Sequence[CacheControl]] = None,
+    content_disposition: typing.Optional[builtins.str] = None,
+    content_encoding: typing.Optional[builtins.str] = None,
+    content_language: typing.Optional[builtins.str] = None,
+    content_type: typing.Optional[builtins.str] = None,
+    destination_key_prefix: typing.Optional[builtins.str] = None,
+    distribution: typing.Optional[_IDistribution_685deca5] = None,
+    distribution_paths: typing.Optional[typing.Sequence[builtins.str]] = None,
+    ephemeral_storage_size: typing.Optional[_Size_7fbd4337] = None,
+    exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+    expires: typing.Optional[_Expiration_505df041] = None,
+    include: typing.Optional[typing.Sequence[builtins.str]] = None,
+    log_retention: typing.Optional[_RetentionDays_6c560d31] = None,
+    memory_limit: typing.Optional[jsii.Number] = None,
+    metadata: typing.Optional[typing.Union[UserDefinedObjectMetadata, typing.Dict[builtins.str, typing.Any]]] = None,
+    prune: typing.Optional[builtins.bool] = None,
+    retain_on_delete: typing.Optional[builtins.bool] = None,
+    role: typing.Optional[_IRole_59af6f50] = None,
+    server_side_encryption: typing.Optional[ServerSideEncryption] = None,
+    server_side_encryption_aws_kms_key_id: typing.Optional[builtins.str] = None,
+    server_side_encryption_customer_algorithm: typing.Optional[builtins.str] = None,
+    storage_class: typing.Optional[StorageClass] = None,
+    use_efs: typing.Optional[builtins.bool] = None,
+    vpc: typing.Optional[_IVpc_6d1f76c4] = None,
+    vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_1284e62c, typing.Dict[builtins.str, typing.Any]]] = None,
+    website_redirect_location: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__63ac57a06200a61758095b95c015c6a89dd2c2d0f1031625cc464895d885f244(
+    s: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6e380cb78dc6be9797c938d16dfd2c73a4567a913ef68de792bd7d4894aa2335(
+    t: _Duration_070aa057,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2c40c18bdc0f9191795b33374a3b1056cd977cf7614535d0deaddfe94ccecfe2(
+    t: _Duration_070aa057,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5d54cbf804b63cfb2ffd1e2c4038a59fe3f522477e771c77cad74a7f0a4492bb(
+    *,
+    handler_role: _IRole_59af6f50,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__df948c6d3f1075ea8cbd38cfea4f31ce644f2052efc011e24c399d607f355fc8(
+    t: _Duration_070aa057,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e606be861e3c298a117f64775c8468e1daaeaa2a690e91e9b2f66a68265d6d79(
+    d: datetime.datetime,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7797f22c13870d77c891043d953f51097c305b01b94ccded2ee925dd48fe3815(
+    t: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d1d19dbd8113e684f139b09164d515078cb3ed1b76d6a5b727ba020391deff61(
+    s: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__34bd2c4be800507ae42bfba48dd15c222308216cdfa18eecba877d068f98c693(
+    scope: _Construct_e78e779f,
+    *,
+    handler_role: _IRole_59af6f50,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d0e3f5e3756c8d34bb7fadf7ccdeaeb9aa74917649593c3b793baf9cd396a818(
+    path: builtins.str,
+    *,
+    readers: typing.Optional[typing.Sequence[_IGrantable_4c5a91d1]] = None,
+    source_hash: typing.Optional[builtins.str] = None,
+    exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+    follow: typing.Optional[_FollowMode_98b05cc5] = None,
+    ignore_mode: typing.Optional[_IgnoreMode_31d8bf46] = None,
+    follow_symlinks: typing.Optional[_SymlinkFollowMode_abf4527a] = None,
+    asset_hash: typing.Optional[builtins.str] = None,
+    asset_hash_type: typing.Optional[_AssetHashType_49193809] = None,
+    bundling: typing.Optional[typing.Union[_BundlingOptions_ab115a99, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c119728ece64deaffc61f6de12dff79ec0b07514b449485478ba54f87952e04a(
+    bucket: _IBucket_73486e29,
+    zip_object_key: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__130a872dd9f4cdb85f52703bfd9fd24c41640fccfb6faace0689610ecc0e29e8(
+    object_key: builtins.str,
+    data: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4ea12f1ef8b32f7ae9db75283fc5bd8f2edf28e6b1b2d855f685233dfe3bc40c(
+    object_key: builtins.str,
+    obj: typing.Any,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a51cfd65f7a1ece82f3b56d790bdbaa329fb34b61c2b856ca6066bd0438eaae5(
+    *,
+    bucket: _IBucket_73486e29,
+    zip_object_key: builtins.str,
+    markers: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
