@@ -50,9 +50,11 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from .._jsii import *
 
-import constructs
+import constructs as _constructs_77d1e7e8
 from .. import (
     CfnResource as _CfnResource_e0a482dc,
     CfnTag as _CfnTag_95fbdc29,
@@ -119,6 +121,10 @@ class CfnProfilePermission(
         :param statement_id: A unique identifier for the cross-account permission statement.
         :param profile_version: The version of the signing profile.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__caaf21b5777859d36ee4d014aef1155691dc35d9544ed307a994009a84b0e6de)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnProfilePermissionProps(
             action=action,
             principal=principal,
@@ -135,6 +141,9 @@ class CfnProfilePermission(
 
         :param inspector: - tree inspector to collect and process attributes.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__170c67cc15c5c7c91dfc1b442e6f8abb136cb24b3bb0f4cf8da3d191b11444e3)
+            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
     @jsii.member(jsii_name="renderProperties")
@@ -145,20 +154,23 @@ class CfnProfilePermission(
         '''
         :param props: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__0c3663a5fe38bc8aa13555cf5684f98505b48610742b8dcf6a6cc792c30e5b2f)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
     def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         '''The CloudFormation resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="action")
     def action(self) -> builtins.str:
         '''The AWS Signer action permitted as part of cross-account permissions.
@@ -169,9 +181,12 @@ class CfnProfilePermission(
 
     @action.setter
     def action(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__fd3d1bff7fff3d1877ce3093571a002bd520f8161d1c367903cb284570588010)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "action", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="principal")
     def principal(self) -> builtins.str:
         '''The AWS principal receiving cross-account permissions.
@@ -184,9 +199,12 @@ class CfnProfilePermission(
 
     @principal.setter
     def principal(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__ea70f9fe9d64668c5454b507a8f3e2f7bab7e81c03e3acaeb5cd2d924d302190)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "principal", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="profileName")
     def profile_name(self) -> builtins.str:
         '''The human-readable name of the signing profile.
@@ -197,9 +215,12 @@ class CfnProfilePermission(
 
     @profile_name.setter
     def profile_name(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__2b984ea6fa71d05fd0641de19fcf9aec4dbffab7bf0e9b504876c2784c342274)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "profileName", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="statementId")
     def statement_id(self) -> builtins.str:
         '''A unique identifier for the cross-account permission statement.
@@ -210,9 +231,12 @@ class CfnProfilePermission(
 
     @statement_id.setter
     def statement_id(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__28eabd0c20825ec7c5dd3d3833d1f3c78975bdb003a5b878cd1612f2ca38bb90)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "statementId", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="profileVersion")
     def profile_version(self) -> typing.Optional[builtins.str]:
         '''The version of the signing profile.
@@ -223,6 +247,9 @@ class CfnProfilePermission(
 
     @profile_version.setter
     def profile_version(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__719f9a9a07622a0d3bdb52e1e7b6cc81f79700cff8a88402ce423082658573e5)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "profileVersion", value)
 
 
@@ -274,7 +301,14 @@ class CfnProfilePermissionProps:
                 profile_version="profileVersion"
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__c33858a67e8e4762b2fd9b2fcdedc543185f3006436941a08c4b53b46df9774c)
+            check_type(argname="argument action", value=action, expected_type=type_hints["action"])
+            check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
+            check_type(argname="argument profile_name", value=profile_name, expected_type=type_hints["profile_name"])
+            check_type(argname="argument statement_id", value=statement_id, expected_type=type_hints["statement_id"])
+            check_type(argname="argument profile_version", value=profile_version, expected_type=type_hints["profile_version"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "action": action,
             "principal": principal,
             "profile_name": profile_name,
@@ -387,8 +421,8 @@ class CfnSigningProfile(
         id: builtins.str,
         *,
         platform_id: builtins.str,
-        signature_validity_period: typing.Optional[typing.Union["CfnSigningProfile.SignatureValidityPeriodProperty", _IResolvable_a771d0ef]] = None,
-        tags: typing.Optional[typing.Sequence[_CfnTag_95fbdc29]] = None,
+        signature_validity_period: typing.Optional[typing.Union[typing.Union["CfnSigningProfile.SignatureValidityPeriodProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
+        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''Create a new ``AWS::Signer::SigningProfile``.
 
@@ -398,6 +432,10 @@ class CfnSigningProfile(
         :param signature_validity_period: The validity period override for any signature generated using this signing profile. If unspecified, the default is 135 months.
         :param tags: A list of tags associated with the signing profile.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__15df35dab0900561aa23ebb2a202ecdaae3e2b57b9f997f79218d99dc46a5d36)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnSigningProfileProps(
             platform_id=platform_id,
             signature_validity_period=signature_validity_period,
@@ -412,6 +450,9 @@ class CfnSigningProfile(
 
         :param inspector: - tree inspector to collect and process attributes.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__9d9889314b94aa7c1e195e9426d187bb2df0375edd95d792387bb2558dbb3450)
+            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
     @jsii.member(jsii_name="renderProperties")
@@ -422,15 +463,18 @@ class CfnSigningProfile(
         '''
         :param props: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__65f0f8dba15477a3c2c704a7a20c43db528f952bd77539c374fac2a3275ac525)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
     def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         '''The CloudFormation resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         '''
@@ -438,7 +482,7 @@ class CfnSigningProfile(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrProfileName")
     def attr_profile_name(self) -> builtins.str:
         '''
@@ -446,7 +490,7 @@ class CfnSigningProfile(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrProfileName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrProfileVersion")
     def attr_profile_version(self) -> builtins.str:
         '''
@@ -454,7 +498,7 @@ class CfnSigningProfile(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrProfileVersion"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrProfileVersionArn")
     def attr_profile_version_arn(self) -> builtins.str:
         '''
@@ -462,12 +506,12 @@ class CfnSigningProfile(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrProfileVersionArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_0b7ab120:
         '''A list of tags associated with the signing profile.
@@ -476,7 +520,7 @@ class CfnSigningProfile(
         '''
         return typing.cast(_TagManager_0b7ab120, jsii.get(self, "tags"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="platformId")
     def platform_id(self) -> builtins.str:
         '''The ID of a platform that is available for use by a signing profile.
@@ -487,9 +531,12 @@ class CfnSigningProfile(
 
     @platform_id.setter
     def platform_id(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__c0580cc6837a072647f927718458b71913ad8bd82562491c22f577d0645909fe)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "platformId", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="signatureValidityPeriod")
     def signature_validity_period(
         self,
@@ -507,6 +554,9 @@ class CfnSigningProfile(
         self,
         value: typing.Optional[typing.Union["CfnSigningProfile.SignatureValidityPeriodProperty", _IResolvable_a771d0ef]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__67eab55e625fe1e664dcd2711c25337a000173c8944680e3a8413bfd3b36b99b)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "signatureValidityPeriod", value)
 
     @jsii.data_type(
@@ -540,7 +590,11 @@ class CfnSigningProfile(
                     value=123
                 )
             '''
-            self._values: typing.Dict[str, typing.Any] = {}
+            if __debug__:
+                type_hints = typing.get_type_hints(_typecheckingstub__d6e9aebf0afed5b4877fbb73feae575f22e40042ca3af644767b6afac3d8e4c3)
+                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
+                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+            self._values: typing.Dict[builtins.str, typing.Any] = {}
             if type is not None:
                 self._values["type"] = type
             if value is not None:
@@ -590,8 +644,8 @@ class CfnSigningProfileProps:
         self,
         *,
         platform_id: builtins.str,
-        signature_validity_period: typing.Optional[typing.Union[CfnSigningProfile.SignatureValidityPeriodProperty, _IResolvable_a771d0ef]] = None,
-        tags: typing.Optional[typing.Sequence[_CfnTag_95fbdc29]] = None,
+        signature_validity_period: typing.Optional[typing.Union[typing.Union[CfnSigningProfile.SignatureValidityPeriodProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
+        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''Properties for defining a ``CfnSigningProfile``.
 
@@ -622,7 +676,12 @@ class CfnSigningProfileProps:
                 )]
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__45773c80085173170b820c348b4f674be33a4f3ab5d90580b678ec3271cc7ee4)
+            check_type(argname="argument platform_id", value=platform_id, expected_type=type_hints["platform_id"])
+            check_type(argname="argument signature_validity_period", value=signature_validity_period, expected_type=type_hints["signature_validity_period"])
+            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "platform_id": platform_id,
         }
         if signature_validity_period is not None:
@@ -681,7 +740,7 @@ class ISigningProfile(_IResource_8c1dbbbd, typing_extensions.Protocol):
     :stability: experimental
     '''
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="signingProfileArn")
     def signing_profile_arn(self) -> builtins.str:
         '''(experimental) The ARN of the signing profile.
@@ -691,7 +750,7 @@ class ISigningProfile(_IResource_8c1dbbbd, typing_extensions.Protocol):
         '''
         ...
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="signingProfileName")
     def signing_profile_name(self) -> builtins.str:
         '''(experimental) The name of signing profile.
@@ -701,7 +760,7 @@ class ISigningProfile(_IResource_8c1dbbbd, typing_extensions.Protocol):
         '''
         ...
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="signingProfileVersion")
     def signing_profile_version(self) -> builtins.str:
         '''(experimental) The version of signing profile.
@@ -711,7 +770,7 @@ class ISigningProfile(_IResource_8c1dbbbd, typing_extensions.Protocol):
         '''
         ...
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="signingProfileVersionArn")
     def signing_profile_version_arn(self) -> builtins.str:
         '''(experimental) The ARN of signing profile version.
@@ -723,7 +782,7 @@ class ISigningProfile(_IResource_8c1dbbbd, typing_extensions.Protocol):
 
 
 class _ISigningProfileProxy(
-    jsii.proxy_for(_IResource_8c1dbbbd) # type: ignore[misc]
+    jsii.proxy_for(_IResource_8c1dbbbd), # type: ignore[misc]
 ):
     '''(experimental) A Signer Profile.
 
@@ -732,7 +791,7 @@ class _ISigningProfileProxy(
 
     __jsii_type__: typing.ClassVar[str] = "monocdk.aws_signer.ISigningProfile"
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="signingProfileArn")
     def signing_profile_arn(self) -> builtins.str:
         '''(experimental) The ARN of the signing profile.
@@ -742,7 +801,7 @@ class _ISigningProfileProxy(
         '''
         return typing.cast(builtins.str, jsii.get(self, "signingProfileArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="signingProfileName")
     def signing_profile_name(self) -> builtins.str:
         '''(experimental) The name of signing profile.
@@ -752,7 +811,7 @@ class _ISigningProfileProxy(
         '''
         return typing.cast(builtins.str, jsii.get(self, "signingProfileName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="signingProfileVersion")
     def signing_profile_version(self) -> builtins.str:
         '''(experimental) The version of signing profile.
@@ -762,7 +821,7 @@ class _ISigningProfileProxy(
         '''
         return typing.cast(builtins.str, jsii.get(self, "signingProfileVersion"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="signingProfileVersionArn")
     def signing_profile_version_arn(self) -> builtins.str:
         '''(experimental) The ARN of signing profile version.
@@ -798,13 +857,13 @@ class Platform(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_signer.Platform")
         
         lambda_.Function(self, "Function",
             code_signing_config=code_signing_config,
-            runtime=lambda_.Runtime.NODEJS_12_X,
+            runtime=lambda_.Runtime.NODEJS_16_X,
             handler="index.handler",
             code=lambda_.Code.from_asset(path.join(__dirname, "lambda-handler"))
         )
     '''
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="AMAZON_FREE_RTOS_DEFAULT")
     def AMAZON_FREE_RTOS_DEFAULT(cls) -> "Platform":
         '''(experimental) Specification of signature format and signing algorithms with SHA256 hash and ECDSA encryption for Amazon FreeRTOS.
@@ -813,7 +872,7 @@ class Platform(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_signer.Platform")
         '''
         return typing.cast("Platform", jsii.sget(cls, "AMAZON_FREE_RTOS_DEFAULT"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="AMAZON_FREE_RTOS_TI_CC3220SF")
     def AMAZON_FREE_RTOS_TI_CC3220_SF(cls) -> "Platform":
         '''(experimental) Specification of signature format and signing algorithms with SHA1 hash and RSA encryption for Amazon FreeRTOS.
@@ -822,7 +881,7 @@ class Platform(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_signer.Platform")
         '''
         return typing.cast("Platform", jsii.sget(cls, "AMAZON_FREE_RTOS_TI_CC3220SF"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="AWS_IOT_DEVICE_MANAGEMENT_SHA256_ECDSA")
     def AWS_IOT_DEVICE_MANAGEMENT_SHA256_ECDSA(cls) -> "Platform":
         '''(experimental) Specification of signature format and signing algorithms for AWS IoT Device.
@@ -831,7 +890,7 @@ class Platform(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_signer.Platform")
         '''
         return typing.cast("Platform", jsii.sget(cls, "AWS_IOT_DEVICE_MANAGEMENT_SHA256_ECDSA"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="AWS_LAMBDA_SHA384_ECDSA")
     def AWS_LAMBDA_SHA384_ECDSA(cls) -> "Platform":
         '''(experimental) Specification of signature format and signing algorithms for AWS Lambda.
@@ -840,7 +899,7 @@ class Platform(metaclass=jsii.JSIIMeta, jsii_type="monocdk.aws_signer.Platform")
         '''
         return typing.cast("Platform", jsii.sget(cls, "AWS_LAMBDA_SHA384_ECDSA"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="platformId")
     def platform_id(self) -> builtins.str:
         '''(experimental) The id of signing platform.
@@ -860,8 +919,8 @@ class SigningProfile(
     '''(experimental) Defines a Signing Profile.
 
     :stability: experimental
-    :exampleMetadata: infused
     :resource: AWS::Signer::SigningProfile
+    :exampleMetadata: infused
 
     Example::
 
@@ -878,7 +937,7 @@ class SigningProfile(
         
         lambda_.Function(self, "Function",
             code_signing_config=code_signing_config,
-            runtime=lambda_.Runtime.NODEJS_12_X,
+            runtime=lambda_.Runtime.NODEJS_16_X,
             handler="index.handler",
             code=lambda_.Code.from_asset(path.join(__dirname, "lambda-handler"))
         )
@@ -886,7 +945,7 @@ class SigningProfile(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         platform: Platform,
@@ -902,6 +961,10 @@ class SigningProfile(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__60cde27332c8b255d1f61c33cd58210b9de1151ec3e78aacf67ed85b4cf2ef42)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = SigningProfileProps(
             platform=platform,
             signature_validity=signature_validity,
@@ -910,11 +973,11 @@ class SigningProfile(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromSigningProfileAttributes") # type: ignore[misc]
+    @jsii.member(jsii_name="fromSigningProfileAttributes")
     @builtins.classmethod
     def from_signing_profile_attributes(
         cls,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         signing_profile_name: builtins.str,
@@ -929,6 +992,10 @@ class SigningProfile(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__8f3d9e0d0932cf8c7fddb3d79164f9296ae351076b1dfee04e51bab5b3d0d5b4)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         attrs = SigningProfileAttributes(
             signing_profile_name=signing_profile_name,
             signing_profile_version=signing_profile_version,
@@ -936,7 +1003,7 @@ class SigningProfile(
 
         return typing.cast(ISigningProfile, jsii.sinvoke(cls, "fromSigningProfileAttributes", [scope, id, attrs]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="signingProfileArn")
     def signing_profile_arn(self) -> builtins.str:
         '''(experimental) The ARN of the signing profile.
@@ -945,7 +1012,7 @@ class SigningProfile(
         '''
         return typing.cast(builtins.str, jsii.get(self, "signingProfileArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="signingProfileName")
     def signing_profile_name(self) -> builtins.str:
         '''(experimental) The name of signing profile.
@@ -954,7 +1021,7 @@ class SigningProfile(
         '''
         return typing.cast(builtins.str, jsii.get(self, "signingProfileName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="signingProfileVersion")
     def signing_profile_version(self) -> builtins.str:
         '''(experimental) The version of signing profile.
@@ -963,7 +1030,7 @@ class SigningProfile(
         '''
         return typing.cast(builtins.str, jsii.get(self, "signingProfileVersion"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="signingProfileVersionArn")
     def signing_profile_version_arn(self) -> builtins.str:
         '''(experimental) The ARN of signing profile version.
@@ -1007,7 +1074,11 @@ class SigningProfileAttributes:
                 signing_profile_version="signingProfileVersion"
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__e7113571747bd941b4b1e3578a032ce2d96908142a4a5feda43f7aa06d27e452)
+            check_type(argname="argument signing_profile_name", value=signing_profile_name, expected_type=type_hints["signing_profile_name"])
+            check_type(argname="argument signing_profile_version", value=signing_profile_version, expected_type=type_hints["signing_profile_version"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "signing_profile_name": signing_profile_name,
             "signing_profile_version": signing_profile_version,
         }
@@ -1085,12 +1156,17 @@ class SigningProfileProps:
             
             lambda_.Function(self, "Function",
                 code_signing_config=code_signing_config,
-                runtime=lambda_.Runtime.NODEJS_12_X,
+                runtime=lambda_.Runtime.NODEJS_16_X,
                 handler="index.handler",
                 code=lambda_.Code.from_asset(path.join(__dirname, "lambda-handler"))
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__46954a7092a77c28a1cf5142f1a7eb92ec438b4c1c968d2ef8111b35e08b33af)
+            check_type(argname="argument platform", value=platform, expected_type=type_hints["platform"])
+            check_type(argname="argument signature_validity", value=signature_validity, expected_type=type_hints["signature_validity"])
+            check_type(argname="argument signing_profile_name", value=signing_profile_name, expected_type=type_hints["signing_profile_name"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "platform": platform,
         }
         if signature_validity is not None:
@@ -1156,3 +1232,159 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__caaf21b5777859d36ee4d014aef1155691dc35d9544ed307a994009a84b0e6de(
+    scope: _Construct_e78e779f,
+    id: builtins.str,
+    *,
+    action: builtins.str,
+    principal: builtins.str,
+    profile_name: builtins.str,
+    statement_id: builtins.str,
+    profile_version: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__170c67cc15c5c7c91dfc1b442e6f8abb136cb24b3bb0f4cf8da3d191b11444e3(
+    inspector: _TreeInspector_1cd1894e,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0c3663a5fe38bc8aa13555cf5684f98505b48610742b8dcf6a6cc792c30e5b2f(
+    props: typing.Mapping[builtins.str, typing.Any],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fd3d1bff7fff3d1877ce3093571a002bd520f8161d1c367903cb284570588010(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ea70f9fe9d64668c5454b507a8f3e2f7bab7e81c03e3acaeb5cd2d924d302190(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2b984ea6fa71d05fd0641de19fcf9aec4dbffab7bf0e9b504876c2784c342274(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__28eabd0c20825ec7c5dd3d3833d1f3c78975bdb003a5b878cd1612f2ca38bb90(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__719f9a9a07622a0d3bdb52e1e7b6cc81f79700cff8a88402ce423082658573e5(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c33858a67e8e4762b2fd9b2fcdedc543185f3006436941a08c4b53b46df9774c(
+    *,
+    action: builtins.str,
+    principal: builtins.str,
+    profile_name: builtins.str,
+    statement_id: builtins.str,
+    profile_version: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__15df35dab0900561aa23ebb2a202ecdaae3e2b57b9f997f79218d99dc46a5d36(
+    scope: _Construct_e78e779f,
+    id: builtins.str,
+    *,
+    platform_id: builtins.str,
+    signature_validity_period: typing.Optional[typing.Union[typing.Union[CfnSigningProfile.SignatureValidityPeriodProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
+    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9d9889314b94aa7c1e195e9426d187bb2df0375edd95d792387bb2558dbb3450(
+    inspector: _TreeInspector_1cd1894e,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__65f0f8dba15477a3c2c704a7a20c43db528f952bd77539c374fac2a3275ac525(
+    props: typing.Mapping[builtins.str, typing.Any],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c0580cc6837a072647f927718458b71913ad8bd82562491c22f577d0645909fe(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__67eab55e625fe1e664dcd2711c25337a000173c8944680e3a8413bfd3b36b99b(
+    value: typing.Optional[typing.Union[CfnSigningProfile.SignatureValidityPeriodProperty, _IResolvable_a771d0ef]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d6e9aebf0afed5b4877fbb73feae575f22e40042ca3af644767b6afac3d8e4c3(
+    *,
+    type: typing.Optional[builtins.str] = None,
+    value: typing.Optional[jsii.Number] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__45773c80085173170b820c348b4f674be33a4f3ab5d90580b678ec3271cc7ee4(
+    *,
+    platform_id: builtins.str,
+    signature_validity_period: typing.Optional[typing.Union[typing.Union[CfnSigningProfile.SignatureValidityPeriodProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
+    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__60cde27332c8b255d1f61c33cd58210b9de1151ec3e78aacf67ed85b4cf2ef42(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    platform: Platform,
+    signature_validity: typing.Optional[_Duration_070aa057] = None,
+    signing_profile_name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8f3d9e0d0932cf8c7fddb3d79164f9296ae351076b1dfee04e51bab5b3d0d5b4(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    signing_profile_name: builtins.str,
+    signing_profile_version: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e7113571747bd941b4b1e3578a032ce2d96908142a4a5feda43f7aa06d27e452(
+    *,
+    signing_profile_name: builtins.str,
+    signing_profile_version: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__46954a7092a77c28a1cf5142f1a7eb92ec438b4c1c968d2ef8111b35e08b33af(
+    *,
+    platform: Platform,
+    signature_validity: typing.Optional[_Duration_070aa057] = None,
+    signing_profile_name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
