@@ -29,9 +29,11 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from .._jsii import *
 
-import constructs
+import constructs as _constructs_77d1e7e8
 from ..aws_lambda import LayerVersion as _LayerVersion_34d6006f
 
 
@@ -55,13 +57,17 @@ class KubectlLayer(
         fn.add_layers(KubectlLayer(self, "KubectlLayer"))
     '''
 
-    def __init__(self, scope: constructs.Construct, id: builtins.str) -> None:
+    def __init__(self, scope: _constructs_77d1e7e8.Construct, id: builtins.str) -> None:
         '''
         :param scope: -
         :param id: -
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__1d959891a2b5b57fac0f58709df70d8838a760860194b3512568998bdcb7c3fd)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         jsii.create(self.__class__, self, [scope, id])
 
 
@@ -70,3 +76,10 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__1d959891a2b5b57fac0f58709df70d8838a760860194b3512568998bdcb7c3fd(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
